package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut


__DATA__
M?T5,1@$!`0````````````(``P`!````=)D$"#0````XL@```````#0`(``)
M`"@`'``;``8````T````-(`$"#2`!`@@`0``(`$```4````$`````P```%0!
M``!4@00(5($$"!,````3````!`````$````!``````````"`!`@`@`0(G*H`
M`)RJ```%`````!````$```#(K@``R#X%",@^!0AH`@``K!(```8`````$```
M`@```-2N``#4/@4(U#X%""@!```H`0``!@````0````$````:`$``&B!!`AH
M@00(1````$0````$````!````%#E=&1@I```8"0%"&`D!0CL````[`````0`
M```$````4>5T9```````````````````````````!@```!````!2Y71DR*X`
M`,@^!0C(/@4(.`$``#@!```$`````0```"]L:6(O;&0M;&EN=7@N<V\N,@``
M!````!`````!````1TY5```````"````!@```"`````$````%`````,```!'
M3E4`!_M<6QK[LPEO-@L?"(2A?/9*V'`E````1@````@````(`````!P0!"5`
M!((X`4`!HH8!J,`!``)+*`0I.*(R1XH$"`A&````2```````````````````
M`$H```!,````30````````!.````3P```%$```!2````4P```%0`````````
M5@``````````````5P```%@```!;``````````````!<````7@```%\```!A
M`````````&,```!E``````````````!G````:````&D`````````R-6R<5GH
M[>S.WD<MH^#[2>K3[PZGW:-K+\6;MMO-XYZ'^9R!5J2;EFL)0]8Y\HL<#3J7
M"\6)!9`,%.*>B0=PTR'_Y`X+BA!7Q+F<0&I_FGRS`8MO?ZF<FV[%WQ_9<5@<
MN^.2?*Q+X\#59-1\X*<""C-BV^UZ\$IK9Z_,9D)%U>SC1\8!?4&.Q</E/RSZ
MH6Q@N8WQ#@`````````````````````F`P`````````````2````S`,`````
M````````$@```&,"`````````````!(````,```````````````@````;00`
M````````````$@```+T#`````````````!(```#>`0`````````````2````
M00,`````````````$@```+D!`````````````!(````M`P`````````````2
M````RP``````````````$@```-D!`````````````!(```#=`@``````````
M```2````>@,`````````````$@```.X"`````````````!(```#Z`0``````
M```````2````B@,`````````````$@```($#`````````````!(```"K`0``
M```````````2````QP$`````````````$@```,```````````````!(```#L
M`0`````````````2````K`(`````````````$@```%L"`````````````!(`
M```*`P`````````````2`````P$`````````````$@```/L"````````````
M`!(````/`0`````````````2````Y@``````````````$@```)$#````````
M`````!(````H```````````````@````O@(`````````````$@```)X#````
M`````````!(```!^```````````````2````&`,`````````````$@```-,#
M`````````````!(```!4`@`````````````2````]@``````````````$@``
M`#H!`````````````!(```"D```````````````2````'P,`````````````
M$@```/4"`````````````!(```#+`@`````````````2````?`(`````````
M````$@````,#`````````````!(```!E```````````````2````V@``````
M````````$@```$@#`````````````!(```!S```````````````2````KP``
M````````````$@```,4#`````````````!(```!=`0`````````````2````
M$0,`````````````$@```$\!`````````````!(````W```````````````@
M````G`$`````````````$@```.,!`````````````!(```"E`P``````````
M```2````,P,`````````````$@```(T``````````````!(```!+````````
M```````@````PP(`````````````$@```&D#`````````````!(```!H`@``
M```````````2````5@,`````````````$@```(T"`````````````!(```#4
M`@`````````````2````80,`````````````$@```*\#`````````````!(`
M```6`0``\)4$"``````2````Y00``&C%!`@$````$0`/`)L$```PM`0(<`L`
M`!(`#0#L!```X+`$"*\!```2``T`1`0``%3%!`@`````$@`.`.<#``!`004(
M!````"$`&0!*!```\*T$"`4````2``T`RP0``.#$!`AA````$@`-`"D!``"P
ME@0(`````!(```"1`0``2$$%"`0````1`!D`J`0``"!!!0@`````$``8`',#
M``!$004(!````!$`&0"J!```($$%"``````@`!@`Y@,``$!!!0@$````(0`9
M`#H$``!0Q00(`@```!(`#0#;!```+$$%"`0````1`!@``04```"N!`C%`0``
M$@`-`(0!``!,004(`0```!$`&0#E`P``0$$%"`0````1`!D`X`,``)"7!`CD
M`0``$@`-`"`%``"0L@0(1````!(`#0!;!```X+($""0````2``T`=@0``-##
M!`AS````$@`-`/8#```P004(`````!``&0`"!```=%$%"``````0`!D`G0(`
M`&S%!`@$````$0`/`$H%``"@OP0(*P0``!(`#0"U!```(*T$",$````2``T`
MK@0``'29!`@`````$@`-`'0!``#`DP0(`````!(```"/!````+`$".`````2
M``T`[P,``#!!!0@`````$``8`(($``#0KP0(+0```!(`#0`N!0``4,0$"$D`
M```2``T`^00``("L!`@T````$@`-``X%```0LP0($@$``!(`#0#[!````),$
M"``````2``L``&QI8G!E<FPN<V\`7TE435]D97)E9VES=&5R5$U#;&]N951A
M8FQE`%]?9VUO;E]S=&%R=%]?`%]*=E]296=I<W1E<D-L87-S97,`7TE435]R
M96=I<W1E<E1-0VQO;F5486)L90!097)L7W-Y<U]T97)M`'!E<FQ?<&%R<V4`
M4&5R;%]S>7-?:6YI=#,`4&5R;%]S879E7V1E<W1R=6-T;W)?>`!097)L7VYE
M=UA3`%!E<FQ?;F5W6%-?9FQA9W,`<&5R;%]A;&QO8P!P97)L7V-O;G-T<G5C
M=`!097)L7VUG7W-E=`!097)L7V=V7V9E=&-H<'8`4&5R;%]N97=35G!V`%!E
M<FQ?<V%F97-Y<VUA;&QO8P!097)L7V%T9F]R:U]U;FQO8VL`4&5R;%]A=&9O
M<FM?;&]C:P!097)L7V-R;V%K7VYO8V]N=&5X=`!097)L7V%V7V9E=&-H`%!E
M<FQ?8W)O86M?;65M;W)Y7W=R87``8F]O=%]$>6YA3&]A9&5R`%!,7V1O7W5N
M9'5M<`!03%]T:')?:V5Y`%!E<FQ?<W9?<V5T<'9N`%!E<FQ?<W9?<V5T<'8`
M4&5R;%]A=E]S:&EF=`!097)L7W-V7S)P=E]F;&%G<P!P97)L7V9R964`<&5R
M;%]R=6X`4&5R;%]D;W5N=VEN9`!P97)L7V1E<W1R=6-T`&QI8FYS;"YS;RXQ
M`&QI8F1L+G-O+C(`;&EB;2YS;RXV`&QI8F-R>7!T+G-O+C$`;&EB=71I;"YS
M;RXQ`&QI8G!T:')E860N<V\N,`!O<&5N-C0`;'-E96LV-`!R96%D`'!T:')E
M861?9V5T<W!E8VEF:6,`7U]E<G)N;U]L;V-A=&EO;@!C;&]S90!L:6)C+G-O
M+C8`7TE/7W-T9&EN7W5S960`7U]R96=I<W1E<E]A=&9O<FL`97AI=`!S=')N
M8VUP`%]?<W1R9'5P`&-L;W-E9&ER`%]?<W1A8VM?8VAK7V9A:6P`=6YL:6YK
M`&UK9&ER`')E86QL;V,`;65M8VAR`&=E='!I9`!S=')T;VL`<W1R;&5N`&UE
M;7-E=`!S=')S='(`<FUD:7(`7U]F<')I;G1F7V-H:P!M96UC<'D`7U]S=')N
M8W!Y7V-H:P!?7VQX<W1A=#8T`&]P96YD:7(`7U]X<W1A=#8T`'-T9&5R<@!G
M971U:60`<F5A9&QI;FL`97AE8W9P`%]?;65M8W!Y7V-H:P!S=')C:'(`<F5A
M9&1I<C8T`%]?<W!R:6YT9E]C:&L`;65M;6]V90!A8V-E<W,`<W1R8VUP`%]?
M;&EB8U]S=&%R=%]M86EN`%]?96YV:7)O;@!?961A=&$`7U]B<W-?<W1A<G0`
M7V5N9``O=7-R+VQI8B]P97)L-2\U+C$X+C$O:3,X-BUL:6YU>"UT:')E860M
M;75L=&DO0T]210!?7VQI8F-?8W-U7V9I;FD`<&%R7V-U<G)E;G1?97AE8P!G
M971?=7-E<FYA;65?9G)O;5]G971P=W5I9`!P87)?8VQE86YU<`!P87)?8F%S
M96YA;64`<&%R7V1I<FYA;64`<&%R7VUK=&UP9&ER`%]?9&%T85]S=&%R=`!P
M87)?8W5R<F5N=%]E>&5C7W!R;V,`7U]L:6)C7V-S=5]I;FET`&UY7W!A<E]P
M;`!?9G!?:'<`<&%R7VEN:71?96YV`'AS7VEN:70`<&%R7V9I;F1P<F]G`'!A
M<E]S971U<%]L:6)P871H`'!A<E]E;G9?8VQE86X`6%-?26YT97)N86QS7U!!
M4E]#3$5!4E-404-+`%A37TEN=&5R;F%L<U]005)?0D]/5`!'3$E"0U\R+C(`
M1TQ)0D-?,BXP`$=,24)#7S(N,RXT`$=,24)#7S(N,RXR`$=,24)#7S(N-```
M``(``@`#`````@`"``(``@````(```````0``@`"`````@`"````````````
M!0`&``(````"``(````'`````@`"`````@`"``8``````````@`"``(``P`"
M```````'```````"`````@````````````@`!P```````@`(``,`"``#``(`
M`@`'`````0`!``$``0`"``$``0```````0`"``$``@`!``$``0````(``0`!
M``$``0`!``$``0`!``$``0````$``0`!``$``0`!``$``0`"`$0"```0````
M,````!)I:0T```8`8`4``!`````0:6D-```#`&H%`````````0`%`),"```0
M`````````!)I:0T```@`8`4``!````!T&6D)```'`'0%```0````<AEI"0``
M!0"`!0``$````!1I:0T```0`C`4``!`````0:6D-```"`&H%````````_#\%
M"`8?``!`004(!5@``$1!!0@%40``2$$%"`5/``!,004(!5<```Q`!0@'`0``
M$$`%"`<"```40`4(!P,``!A`!0@'!0``'$`%"`<&```@0`4(!P<``"1`!0@'
M"```*$`%"`<)```L0`4(!V,``#!`!0@'"@``-$`%"`<+```X0`4(!PP``#Q`
M!0@'#0``0$`%"`<.``!$0`4(!P\``$A`!0@'$```3$`%"`<1``!00`4(!Q(`
M`%1`!0@'$P``6$`%"`<4``!<0`4(!Q4``&!`!0@'%@``9$`%"`<7``!H0`4(
M!Q@``&Q`!0@'&0``<$`%"`<:``!T0`4(!QL``'A`!0@''```?$`%"`<=``"`
M0`4(!QX``(1`!0@''P``B$`%"`<@``",0`4(!R$``)!`!0@'(@``E$`%"`<C
M``"80`4(!R0``)Q`!0@')0``H$`%"`<F``"D0`4(!R<``*A`!0@'*```K$`%
M"`<I``"P0`4(!RH``+1`!0@'*P``N$`%"`=&``"\0`4(!RP``,!`!0@'+0``
MQ$`%"`<N``#(0`4(!R\``,Q`!0@',```T$`%"`<Q``#40`4(!S(``-A`!0@'
M,P``W$`%"`<T``#@0`4(!S4``.1`!0@'-@``Z$`%"`=.``#L0`4(!S@``/!`
M!0@'.0``]$`%"`<Z``#X0`4(!SL``/Q`!0@'/````$$%"`<^```$004(!S\`
M``A!!0@'0```#$$%"`=!```0004(!T(``!1!!0@'0P``&$$%"`=$```<004(
M!T4``%.#[`CHEP8``('#]ZP``(N#_/___X7`=`7H`@(``(/$"%O#````````
M`````````/\U!$`%"/\E"$`%"`````#_)0Q`!0AH`````.G@_____R400`4(
M:`@```#IT/____\E%$`%"&@0````Z<#_____)1A`!0AH&````.FP_____R4<
M0`4(:"````#IH/____\E($`%"&@H````Z9#_____)21`!0AH,````.F`____
M_R4H0`4(:#@```#I</____\E+$`%"&A`````Z6#_____)3!`!0AH2````.E0
M_____R4T0`4(:%````#I0/____\E.$`%"&A8````Z3#_____)3Q`!0AH8```
M`.D@_____R5`0`4(:&@```#I$/____\E1$`%"&AP````Z0#_____)4A`!0AH
M>````.GP_O___R5,0`4(:(````#IX/[___\E4$`%"&B(````Z=#^____)51`
M!0AHD````.G`_O___R580`4(:)@```#IL/[___\E7$`%"&B@````Z:#^____
M)6!`!0AHJ````.F0_O___R5D0`4(:+````#I@/[___\E:$`%"&BX````Z7#^
M____)6Q`!0AHP````.E@_O___R5P0`4(:,@```#I4/[___\E=$`%"&C0````
MZ4#^____)7A`!0AHV````.DP_O___R5\0`4(:.````#I(/[___\E@$`%"&CH
M````Z1#^____)81`!0AH\````.D`_O___R6(0`4(:/@```#I\/W___\EC$`%
M"&@``0``Z>#]____)9!`!0AH"`$``.G0_?___R640`4(:!`!``#IP/W___\E
MF$`%"&@8`0``Z;#]____)9Q`!0AH(`$``.F@_?___R6@0`4(:"@!``#ID/W_
M__\EI$`%"&@P`0``Z8#]____):A`!0AH.`$``.EP_?___R6L0`4(:$`!``#I
M8/W___\EL$`%"&A(`0``Z5#]____);1`!0AH4`$``.E`_?___R6X0`4(:%@!
M``#I,/W___\EO$`%"&A@`0``Z2#]____)<!`!0AH:`$``.D0_?___R7$0`4(
M:'`!``#I`/W___\ER$`%"&AX`0``Z?#\____)<Q`!0AH@`$``.G@_/___R70
M0`4(:(@!``#IT/S___\EU$`%"&B0`0``Z<#\____)=A`!0AHF`$``.FP_/__
M_R7<0`4(:*`!``#IH/S___\EX$`%"&BH`0``Z9#\____)>1`!0AHL`$``.F`
M_/___R7H0`4(:+@!``#I</S___\E[$`%"&C``0``Z6#\____)?!`!0AHR`$`
M`.E0_/___R7T0`4(:-`!``#I0/S___\E^$`%"&C8`0``Z3#\____)?Q`!0AH
MX`$``.D@_/___R4`004(:.@!``#I$/S___\E!$$%"&CP`0``Z0#\____)0A!
M!0AH^`$``.GP^____R4,004(:``"``#IX/O___\E$$$%"&@(`@``Z=#[____
M)11!!0AH$`(``.G`^____R48004(:!@"``#IL/O___\E'$$%"&@@`@``Z:#[
M__]5B>564X/D\(/L,(U%$(E$)`B-10R)1"0$C44(B00DZ)S]___'1"0(\)4$
M",=$)`3PE00(QP0DL)8$".C0+```@#U,004(`'4NZ*+\__^%P*-P404(#X1]
M`0``B00DZ.W[__^A2$$%"(D$).@P____QH!!!0```*%(004(B00DZ!S___^`
MB.X"```"H4A!!0B)!"3H"/___S'2@(CN`@```8M%"(E4)!R-2`6)3"08WVPD
M&-@%4"0%"-T%6"0%"-G)VNG?X)X/AP<!``#!X0*)#"3H:?S__XMU#(M=",<%
M:%$%"`0```"+%H/[`:-D404(QT`$5<<$"(D0BQ4L004(QT`,6,<$"(E0"+H!
M````?A6-M"8`````BPR6B4R0#(/"`3G:=?+'1)@,`````(/#`XE$)`RA<%$%
M"(E<)`C'1"00`````,=$)`3`K`0(B00DZ&K]__^%P(G#=#JA<%$%"(D$).@W
M^___C50D++@9Q@0(Z(D,``"%P'0LH7!1!0B)!"3HV/K__^@#_?__C67XB=A;
M7EW#H7!1!0B)!"3HG?W__XG#Z[6A;%$%"(7`=`J)!"3HB"H``.O!C50D++C.
MQ00(Z#@,``"%P*-L404(=*KKW>@8_?__QP0D`0```.B\^___,>U>B>&#Y/!0
M5%)H4,4$"&C@Q`0(459HD)<$".C;^___]&:09I!FD&:09I"+'"3#9I!FD&:0
M9I!FD&:0N#-!!0@M,$$%"(/X!G<!P[@`````A<!T]E6)Y8/L&,<$)#!!!0C_
MT,G#C;8`````N#!!!0@M,$$%",'X`HG"P>H?`=#1^'4!P[H`````A=)T]E6)
MY8/L&(E$)`3'!"0P004(_]+)PXGVC;PG`````(`]34$%"`!U$U6)Y8/L".A\
M____Q@5-004(`<GSPV:0H=`^!0B%P'0?N`````"%P'0658GE@^P8QP0DT#X%
M"/_0R>EY____D.ES____9I"055=64X'L6`$``(E$)`B-2!PQP)"-="8`BQ2!
M#\J)5(08@\`!@_@0=>^-5"1,C8PD3`$``(UT)@"+0NR#P@0S0OPS0M`S0LC!
MR!^)0@@YRG7GBT0D"(MP!(M0$(L8B?&+<`B)5"04`U0D&(GUBW`,B2PDB70D
M!(M$)`2)WL'.&XV\,IEY@EJ)SHGJ]]$A\B'("=")\8M4)`0!QXL$)(G=`U0D
M'/?5P<D"B70D$"'HB=TARPG8B?N-M`*9>8):B>K!RQL!WHL<)`-<)"")\,'(
M&XEL)`S!R@*)_8V<`YEY@EJ)^/?0(=4AR`GHB?4!PXGPP<\"]]`#3"0D(?TA
MT`GHB=V-C`&9>8):B=C!R!L!P0-4)"B)R,'(&\'.`HV4`IEY@EJ)V/?0(?4A
M^`GHB<T!PHG(P<L"]]`#?"0L(=TA\`GHB=6-O`>9>8):B=#!R!L!QP-T)#")
M^,'(&\')`HVT!IEY@EJ)T/?0(<TAV`GHB?T!QHGXP<H"]]`#7"0T(=4AR`GH
MB?6-G`.9>8):B?#!R!L!PP-,)#B)V,'(&\'/`HV,`9EY@EJ)\/?0(?TAT`GH
MB=T!P8G8P<X"]]`#5"0\(?4A^`GHB<V-E`*9>8):B<C!R!L!P@-\)$")T,'(
M&\'+`HV\!YEY@EJ)R/?0(=TA\`GHB=4!QXG0P<D"]]`#="1$(<TAV`GHB?V-
MM`:9>8):B?C!R!L!Q@-<)$B)\,'(&\'*`HV<`YEY@EJ)^/?0(=4AR`GHB?4!
MPXGPP<\"]]`#3"1,(?TAT`GHB=V-C`&9>8):B=C!R!L!P0-4)%")R,'.`L'(
M&R'UC90"F7F"6HG8]]`A^`GHB<T!PHG(P<L"]]`#?"14(=TA\`GHB=6-O`>9
M>8):B=#!R!L!QP-T)%B)^,'(&\')`HVT!IEY@EJ)T/?0(<TAV`GHB?T!QHGX
MP<H"]]`#7"1<(=4AR`GHB?6-G`.9>8):B?#!R!L!PP-,)&")V,'(&\'/`HV,
M`9EY@EJ)\/?0(?TAT`GHB=T!P8G8P<X"]]`#5"1D(?4A^`GHC90"F7F"6HG(
MP<L"P<@;`<*)V`-\)&@Q\#'(P<D"C;P'H>O9;HG0P<@;`?B)SP-T)&PQWS'7
MP<H"C;P^H>O9;HG&P<X;`?Z)UP-<)'`QSS''P<@"C;P[H>O9;HGSP<L;`?N)
MQP-,)'0QUS'WP<X"C;PYH>O9;HG9P<D;`?F)]P-4)'B)S3'',=_!S1O!RP*-
MO#JAZ]ENB>H!^HG?`T0D?#'W,<_!R0*-O#BAZ]ENB=#!R!L!^(G/`[0D@```
M`#'?,=?!R@*-O#ZAZ]ENB<;!SAL!_HG7`YPDA````#'/,<?!R`*-O#NAZ]EN
MB?/!RQL!^XG'`XPDB````#'7,??!S@*-O#FAZ]ENB=G!R1L!^8GW`Y0DC```
M`#''B<TQW\'-&XV\.J'KV6Z)Z@'ZP<L"`X0DD````(G?,?<QSXV\.*'KV6Z)
MT,')`L'(&P'XB<\#M"24````,=\QU\'*`HV\/J'KV6Z)QL'.&P'^B=<#G"28
M````,<\QQ\'(`HV\.Z'KV6Z)\\'+&P'[B<<#C"2<````,=<Q]\'.`HV\.:'K
MV6Z)V<')&P'YB?<#E"2@````,<>)S3'?P<T;P<L"C;PZH>O9;HGJ`?J)WP.$
M)*0````Q]S'/P<D"C;PXH>O9;HG0P<@;`?B)SP.T)*@````QWS'7P<H"C;P^
MH>O9;HG&P<X;`?Z)UP.<)*P````QSS''P<@"C;P[H>O9;HGSP<L;`?N)QP.,
M)+`````QUS'WP<X"C;PYH>O9;HG9P<D;`?F)]P.4)+0````QQXG-,=_!S1N-
MO#JAZ]ENB>H!^HN\)+@```#!RP*)W2'U`<>)V`GP(<@)Z`.T)+P```"-O`?<
MO!N/B=#!R0+!R!N)S0'XB?>)SB'="=XAU@.<),`````)[HV\-]R\&X^)QL'*
M`L'.&XG5`?Z)WXG3(<T)RR'#`XPDQ`````GKC;P?W+P;CXGSP<@"P<L;B<4!
M^XG/B<$AU0G1(?$)Z8V\#]R\&X^)V<')&P'YB[PDR````,'.`HGU"<4!UXGJ
MB?4AVB'%">J)S<'-&XV\%]R\&X^)Z@'ZB[PDS````,'+`HG=(?4!QXG8"?`A
MR`.T)-`````)Z(V\!]R\&X^)T,')`L'(&XG-`?B)]XG.(=T)WB'6`YPDU```
M``GNC;PWW+P;CXG&P<H"P<X;B=4!_HG?B=,AS0G+(<,#C"38````">N-O!_<
MO!N/B?/!R`+!RQN)Q0'[B<^)P2'5"=$A\0GIC;P/W+P;CXG9P<D;`?F+O"3<
M````P<X"B?4)Q0'7B>J)]2':(<4)ZHG-P<T;C;P7W+P;CXGJ`?J+O"3@````
MP<L"B=TA]0''B=@)\"'(`[0DY`````GHC;P'W+P;CXG0P<D"P<@;B<T!^(GW
MB<XAW0G>(=8#G"3H````">Z-O#?<O!N/B<;!R@+!SAN)U0'^B=^)TR'-"<LA
MPPGKC;P?W+P;CXGSP<L;`?O!R`(#C"3L````B<4AU8G/B<$)T2'Q">F-O`_<
MO!N/B=G!R1L!^8N\)/````#!S@*)]0G%`=>)ZHGU(=HAQ0GJB<W!S1N-O!?<
MO!N/B>H!^HN\)/0```#!RP*)W2'U`<>)V`GP(<@#M"3X````">B-O`?<O!N/
MB=#!R0+!R!N)S0'XB?>)SB'="=XAU@GNC;PWW+P;CXG&P<X;P<H"`?X#G"3\
M````B=4AS8G?B=,)RR'#`XPD``$```GKC;P?W+P;CXGSP<@"P<L;B<4!^XG/
MB<$AU0G1(?$)Z8V\#]R\&X^)V<')&P'YB[PD!`$``,'.`HGU"<4!UXGJB?4A
MVB'%">J)S<'+`L'-&XV\%]R\&X\![XG=`X0D"`$``#'UB>HQRHV4$-;!8LJ)
M^,')`L'(&XG-`=`QW0.T)`P!``")ZHG%,?K!S1N-M!;6P6+*B>H!\HG^P<X"
M`YPD$`$``(GW,<\QQXV\.];!8LJ)T\'(`L'+&P'[B<<#C"04`0``,?<QU\'*
M`HV\.=;!8LJ)V<')&P'/B=$#M"08`0``,<$QV<'+`HVT#M;!8LJ)^<')&P'.
MB=D#A"0<`0``,=$Q^0.4)"`!``"-C`C6P6+*B?#!R!O!SP(!P8GX,=\Q]XG-
MP<X"P<T;C;PZUL%BR@'OB?4#G"0D`0``,<6)ZHG],<K!S1O!R0*-G!/6P6+*
MB>H!VHG+`X0D*`$``#'S,?O!SP*-G!C6P6+*B=#!R!L!PXGX`[0D+`$``#'(
M,=#!R@*-M`;6P6+*B=C!R!L!\(G6`XPD,`$``#'^,=[!RP*-M#'6P6+*B<'!
MR1L!SHG9`[PD-`$``#'1,<'!R`*-O`_6P6+*B?'!R1L!^8G'`Y0D.`$``#'?
M,?>)S<'-&XV\.M;!8LK!S@(![XGU`YPD/`$``#'%B>J)_3'*P<T;P<D"C9P3
MUL%BRHGJ`=J)RP.$)$`!```Q\S'[P<\"C9P8UL%BRHG0P<@;`<.)^`.T)$0!
M```QR#'0P<H"C;0&UL%BRHG8P<@;`?")U@.,)$@!```Q_C'>P<L"C;0QUL%B
MRHG!P<D;`?&)W@.\)$P!```QUC'&P<@"C;PWUL%BRHG.P<X;`?Z)QP.4)%`!
M``")]3'?,<_!S1N-O#K6P6+*B>J+;"0,`ZPD5`$```'ZP<D"C;PKUL%BRHG-
M,<6)ZXG5,?,!^XM\)`C!S1L!Z\'.`HD?BQPD`U0D$`-,)`0#1"04B5<$C10>
MB5<(B4\,B4<0@<18`0``6UY?7<.-="8`C;PG`````%575HG&4X/L+(7`B50D
M''1+H4!!!0B%P(E$)!AT/@^V!CP]=4,QVXM$)!B+*(7M="N)QY"-="8`B5PD
M"(ET)`2)+"3H./'__X7`=0>`?!T`/70M@\<$BR^%[77<@\0L,<!;7E]=PV:0
MA,!TN8GS@\,!#[8#/#UT!(3`=?(I\^NGBT0D'(GY*TPD&,'Y`HD(@\0LC40=
M`5M>7UW#D(UT)@!3B<.#[!B-5"0,B=CH3____X7`=#:-=@"A0$$%"(M4)`R-
M%)"+2@2%R8D*=-F-=@"#P@2+2@2%R8D*=?2-5"0,B=CH&?___X7`=<V#Q!A;
MPU57B<=6,<!3B=.#[#R`.CT/E,`!PXD<).C#[O__C50D+(G%B?CHYO[__X7`
MB<8/A-P```")!"3HI.[__SG%#X:T````BT0D+(T,A0`````/M@<\/0^$9@$`
M`(3`#X1>`0``B?CK!F:0A-)T"X/``0^V$(#Z/77Q*?B+-4!!!0B-1"@"B00D
M`<[HX^W__X7`B08/A#P!``"A0$$%"(U/`8M4)"R+%)`/M@>$P(@"=1GK&XVT
M)@````"#P0$/MD'_@\(!A,"(`G0$/#UU[,8"/3'`C;0F``````^V#`.(3`(!
M@\`!A,EU\3'`@\0\6UY?7<.-M"8`````@\,!#[9#_X/&`83`B$;_=>_KW)"-
M="8`BQ5`004(BP*%P`^$IP```#'VC;8`````@\8!BP2RA<!U]HT$M0@```"+
M#6!1!0B%R70MB40D!(D4).@1[?__A<"C0$$%"'1[C0RU`````,=$L`0`````
MB70D+.G?_O__B00DB50D&,<%8%$%"`$```#HZNS__X7`=$F+5"08C0RU````
M`(E,)`B)!"2)3"0<B50D!(E$)!CH4^O__XM$)!B+3"0<HT!!!0CKHXUT)@`Q
MP.FR_O__N`@````Q]NEF____N/_____I#/___XUV`%575HG&4X'LC````(7`
M=`6`.`!U"X'$C````%M>7UW#B00DZ.CN__^%P(G'=.>)/"3H2N[__X7`B<,/
MA+````"`>Q,N#X3&````B30DC6L3Z*OL__^)+"2)1"0<Z)_L__^+3"0<C40!
M`HD$).@?[/__B6PD%(ET)!#'1"0,<,4$",=$)`C_____QT0D!`$```")!"2)
MP^B%[O__C40D((E$)`B)7"0$QP0D`P```.@-[O__@_C_=!"+1"0P)0#P```]
M`$```'1PB1PDZ/#J__^)'"3H6.K__XD\).B@[?__A<")PP^%5O___XVV````
M`(D\).@([O__B30DZ'#J__^!Q(P```!;7E]=PY"-="8`#[9#%(3`#X02____
M/"X/A2;___^`>Q4`#X0`____9I#I%?___XUV`(G8Z,'^__^0ZXZ-M"8`````
MC;PG`````%93@^P4H4A!!0B)!"3H;NW__XM`=(MP!*%(004(B00DZ%OM__\/
MMEAAH4A!!0B#XW^)!"3H1^W__XM`!`^W0!#!X`<)V&:)1@*A2$$%"(D$).@J
M[?__BT!TBU@$H4A!!0B)!"3H%^W__\=$)`@`````QT0D!$_'!`B)!"3H7^O_
M_XE#'*%(004(B00DZ._L__^+0'2+6`2A2$$%"(D$).C<[/__BX#P`P``B4,@
MH4A!!0B)!"3HQNS__XM`=(M8!*%(004(B00DZ+/L__\QTHN`#`$``(7`=!:A
M2$$%"(D$).B:[/__BX`,`0``BU!PH4A!!0B)4R2)!"3H@>S__XM`=(M`!,=`
M*`````"A2$$%"(D$).AG[/__BT!TBT`$QT`8`````*%(004(B00DZ$WL__^+
M0'2+6`2A2$$%"(D$).@Z[/__BX`8`@``B4,L@\046U[#C70F`(V\)P````!3
MB<.#[!BA2$$%"(D$).@-[/__B5PD!,<$)`,````%&`$``(E$)`CH!.S__X7`
M=`B#Q!@QP%O#D*%(004(B00DZ-OK__^+@"@!```E`/```#T`0```=!^A2$$%
M"(D$).B\Z___BX`H`0``)0#P```]`*```'6ZB1PDQT0D!`(```#HVNK__X7`
M#Y3`@\08#[;`6\.-M@````"-O"<`````58G55XG'5E.!["P0``"-="0<QT0D
M"/\/``")="0$QP0D=L4$"&6A%````(F$)!P0```QP.AGZ/__A<!^:XU8_X!\
M'!P`=%F)PXE<)`C'1"0$+P```(DT).@#ZO__A<!T1Z%(004(B00DZ!+K__^)
M7"0,B70D"(E\)`2)!"3HCNK__XN$)!P0``!E,P44````=36!Q"P0``!;7E]=
MPXUV`(7;=:6-="8`H4A!!0B)!"3HR^K__XEL)`B)?"0$B00DZ.OG___KN^B$
MY___C70F`(/L'*%(004(B00DZ*#J___'1"0,A<4$",=$)`C`DP0(QT0D!(_%
M!`B)!"3H`.G__X/$',.-M@````"-OP````"#["RA2$$%"(D$).A@ZO__B00D
MZ*C___^A2$$%"(D$).A+ZO__QT0D%`````#'1"003\<$",=$)`Q/QP0(QT0D
M"*"_!`C'1"0$J\4$"(D$).A+Z?__@\0LPXVT)@````!75E.![#`@``!EH10`
M``")A"0L(```,<"-7"0JZ'_G___'1"04@<4$",=$)`S`Q00(QT0D"`$0``#'
M1"0$`0```(D<)(E$)!#H$^K__X7`>&>-O"0K$```B1PDQT0D"``0``")?"0$
MZ,3F__^%P(G#>$:-0`&)!"3H4^?__X7`B<9T-8E<)`B)?"0$B00DZ.WE__^)
M\,8$'@"+E"0L(```93,5%````'43@<0P(```6UY?PY"-="8`,<#KW>@?YO__
MZPV0D)"0D)"0D)"0D)"0Z2O___^-="8`C;PG`````%575E.![#P0``!EH10`
M``")A"0L$```,<"-5"0HN,[%!`B+M"10$```B[PD5!```.A;]___QT0D!"\`
M``")-"2)P^CYYO__A<!T+8GRN-?%!`CH*?C__XGPBY0D+!```&4S%10````/
MA4X!``"!Q#P0``!;7E]=PXDT).C@YO__B3PDC7PD+,=$)`3DQ00(B40D'.CX
MY___B<6-M@````"%[72G@'T``'4%O<S%!`B%VW04B6PD!(D<).B1Y/__A<`/
MA*P```")+"3HD>;__X!\!?\O=1%FD(/H`8!\!?\OQD0%``!T\8M,)!R-1`@!
M/?\/```/CU'___^)="08QT0D%.;%!`B);"00QT0D#`K'!`C'1"0(`!```,=$
M)`0!````B3PDZ%;H__^A2$$%"(D$).CYY___B7PD!,<$)`,````%&`$``(E$
M)`CHT.?__X7`=1^A2$$%"(D$).C/Y___BX`H`0``)0#P```]`(```'0;QT0D
M!.3%!`C'!"0`````Z`GG__^)Q>D2____QT0D!`$```")/"3HTN;__X7`==&)
M^KC7Q00(Z-+V__^)/"3H*N;__^F>_O__D(UT)@#H.^3__XUT)@"-O"<`````
MBT0D!`^V"(3)=""-4`'K"@^V"H/"`83)=!&`^2]U\0^V"HG0@\(!A,EU[_/#
MC78`4X/L&(M<)""%VW0\@#L`=#>)'"3H1^7__XU$`_\YPW(.ZU&0C70F`(/H
M`3G8=`F`."]T].LW9I"`."^0C70F``^%B0```&:0QP0D`@```.B<Y/__A<!T
M<+HN````9HD0@\086\.-=@"`."]T!X/H`3G#<O0YV'4-Z[Z-M@````"`."]U
M!X/H`3G#<O0IV(U0`H'Z`!```'<O@\`!B5PD!,=$)`P`$```B40D",<$)&!!
M!0CHB.7__X/$&+A@004(6\.-M@````"#Q!@QP%O#QT0D(.;%!`B#Q!A;Z0#E
M__]75H/L-&6A%````(E$)"PQP*%<QP0(B40D"J%@QP0(B40D#J%DQP0(B40D
M$J%HQP0(B40D%J%LQP0(B40D&J%PQP0(B40D'J%TQP0(B40D(J%XQP0(B40D
M)@^W!7S'!`AFB40D*KCHQ00(Z.'T__^X\<4$".C7]/__N/G%!`CHS?3__[@"
MQ@0(Z,/T__^X"<8$".BY]/__N!G&!`CHK_3__[C.Q00(Z*7T__^X)<8$".B;
M]/__N"_&!`CHD?3__[@YQ@0(Z(?T__^XU\4$".A]]/__N$/&!`CH<_3__[A,
MQ@0(Z&GT__^-5"0$N%?&!`CHN_/__X7`=`R)PK@OQ@0(Z)OT__^-5"0$N&C&
M!`CHG?/__X7`=`R)PKAZQ@0(Z'WT__^-5"0$N(7&!`CH?_/__X7`=#.)PKC.
MQ00(Z%_T__^ZL<8$"+@)Q@0(Z%#T__^+1"0L93,%%````'5-@\0T7E_#D(UT
M)@"-5"0$N)7&!`CH.O/__X7`=`Z)PK@EQ@0(Z!KT___KN8UT)!N_IL8$"+D*
M````\Z9UIXU4)"6X)<8$".CX\___ZY?H<>'__Y"A*$$%"(/X_W0&PY"-="8`
M@^P<N"7&!`B-5"0,Z-_R__^%P'0;#[80,<"$TG0(,<"`^C`/E<"C*$$%"(/$
M',.0,<#K\HVV`````(V_`````(/L'.@HX?__B00DZ(#@__^%P'0,BP"#Q!S#
MC;8`````,<#K\HVV`````(V_`````%57O[W&!`A64[NSQ@0(@^Q,QT0D)+W&
M!`B-="0LQT0D*+/&!`C'1"0LP,8$",=$)#"VQ@0(QT0D-+O&!`C'1"0XS<8$
M",=$)#P`````ZR*0BT0D8(DL)(E$)`3HT-___X7`=#R%VW0NBP:)WX/&!(G#
MC50D((GXZ`3R__^%P(G%=`6`.`!UR8M4)&")^.C>\O__A=MUTH/$3%M>7UW#
M9I"+1"1@B00DZ*3A__^)+"2)1"0<Z)CA__^+5"0<C40"`HD$).@8X?__B6PD
M&,=$)!3DQ00(QT0D#`K'!`C'1"0(_____\=$)`0!````B<*+1"1@B10DB50D
M'(E$)!#H;N/__XM4)!R)^.AC\O__Z5+___^-M"8`````C;PG`````%575E.!
M[!R!``"+A"0P@0``C50D.,=$)#SDQ@0(QT0D0,S%!`C'1"1$`````(E$)"AE
MH10```")A"0,@0``,<"XSL4$",=$)%1ZQ@0(QT0D6'/&!`C'1"1<Z<8$",=$
M)&"0Q@0(QT0D9/'&!`C'1"1H`````,=$)$C8Q@0(QT0D3/7&!`C'1"10````
M`.C.\/__A<!T"8`X``^%200``)#H"_[__X7`B<,/A%8$``")'"3H>>#__XU$
M``&)!"3H_=___X`[`(G&B<=T-HUT)@`/M@.#PP&)/"2#QP+'1"0,_L8$",=$
M)`C_____B40D$,=$)`0!````Z%/B__^`.P!USHU\)%BX>L8$".L-C78`@\<$
MBT?\A<!T+HU4)#CH/?#__X7`B<-TYX`X`'3BZ*WU__^%P'39B1PDZ''@__^%
MP(G%=4V-=@"+7"0\A=MT0(`[`+\!````=1;K-(UT)@"+7+P\A=MT*(/'`8`[
M`'0@B=CH:?7__X7`=.6)'"3H+>#__X7`=-F)Q>L'D(UT)@`Q[8DL)(GSZ)3?
M__^+"X/#!(V1__[^_O?1(<J!XH"`@(!TZ??"@(```'4&P>H0@\,"`-*#VP,I
M\XV<`P0$``")'"3HZ=[__XET)!S'1"08`\<$",=$)!3FQ00(B6PD$,=$)`P(
MQP0(B<;'1"0(_____\=$)`0!````B00DB40D).@[X?__QT0D!,`!``")-"3H
M>]___X/X_P^$@@```*%(004(B00DZ,7@___'!"0#````!1@!``")1"0(BT0D
M)(E$)`3HN.#__X7`#X28````BT0D)(E$)!"+1"0HBP#'1"0(O,<$",=$)`0!
M````B40D#*%$004(B00DZ#'@__\QP(N,)`R!``!E,PT4````#X6["```@<0<
M@0``6UY?7</H&]___XL`@_@1#X1N____B40D%(M$)"2)1"00BT0D*(L`QT0D
M"(#'!`C'1"0$`0```(E$)`RA1$$%"(D$).C-W___,<#KFI"A2$$%"(D$).C[
MW___BX`H`0``)0#P```]`$````^%1?___Z%(004(B00DZ-C?__^+L#`!``#H
MK=S__SG&#X4E____H4A!!0B)!"3HN-___XN`*`$``"7_`0``/<`!```/A0+_
M__^)'"3H6MW__XU4)#B)Q;BVQ@0(Z.KM__^%P`^$YP<``(D$).@JWO__B40D
M!(M$)"B+`(D$).@X]O__A<")PP^$PP<``(D<).B&W?__@_@#?BF-=`/\OQ''
M!`BY!0```/.F=1>#^`0/A'\&``"`?`/[+P^$=`8``(UV`.B#^O__A<!U',=$
M)`0`````B1PDZ%_=__^%P(E$)"@/A5<!``"ZL<8$"+@EQ@0(Z$3N__\QV^A]
MW/__BW0D),=$)!Q/QP0(QT0D%.;%!`C'1"0,*L<$"(ET)!#'1"0(_____XE$
M)!C'1"0$`0```(DL).@!W___ZU6-M"8`````Z'/=__^#.!%U6>@IW/__@\,!
MQT0D($_'!`B)7"0<QT0D%.;%!`B)="00QT0D##C'!`B)1"08QT0D"/_____'
M1"0$`0```(DL).BJWO__QT0D!,`!``")+"3HZMS__X/X_W2=BT0D)(D$).B9
MVO__B>JXSL4$".A][?__B2PDZ`7Z__^)Z.FO_?__C;8`````B00DB40D).CL
M^?__BT0D)(D$).BPW/__Z8S]__^^`0```+C8Q@0(ZQ*-M"8`````BT2T2(/&
M`87`="6-5"0XZ#3L__^%P'3H@#@`=..)!"3H<]S__X7`=->)P^EG^___L`V[
MW<8$".EG^___QT0D#`(```")QL=$)`3N____QT0D"/____^)!"3H"MO__XV$
M)`P!``#'1"0(!@```(E$)`2)-"3HG]G__X"\)`P!````=0Z`O"0-`0``0P^$
M*@4``(M$)"C'1"0,`````,=$)`0`````QT0D"`````")!"3HL]K__\>$)*P`
M```!(T5GQX0DL````(FKS>_'A"2T````_MRZF,>$)+@```!V5#(0QX0DO```
M`/#ATL/'A"3``````````,>$),0`````````QX0D"`$```````");"0LC;0F
M`````(V$)`P!``")1"0$BT0D*,=$)`@`@```B00DZ.'8__^%P(G&#X[.`0``
MBY0DP````(T$\CG"#X>M`0``BY0DQ````(F$),````")\,'H'0'0B80DQ```
M`(N$)`@!``"%P`^$<@$``+I`````B?<IPCG6?@*)UXV$!,@```"-C"0,`0``
MB7PD"(E,)`2)!"3HK=C__XN$)`@!```!^(/X0(F$)`@!```/A53___^-A"0,
M`0``*?X!QXV$)*P```#H3=___Y"-="8`@_X_#X[6````B?6)^XUV`(L#@^U`
M@\-`B80DR````(M#Q(F$),P```"+0\B)A"30````BT/,B80DU````(M#T(F$
M)-@```"+0]2)A"3<````BT/8B80DX````(M#W(F$).0```"+0^")A"3H````
MBT/DB80D[````(M#Z(F$)/````"+0^R)A"3T````BT/PB80D^````(M#](F$
M)/P```"+0_B)A"0``0``BT/\B80D!`$``(V$)*P```#HA][__X/]/P^/1O__
M_X/N0(GRP>H&C4(!P>`&P>(&`<<IUHV$),@```#'1"0,1````(ET)`B)?"0$
MB00DZ.K8__^)M"0(`0``Z2[^__^-M@````"-O"0,`0``Z>3^__^-="8`BXPD
MQ````(U1`>E+_O__BT0D*(ML)"R)!"3HZ=K__XN<),````"+M"3$````B=C!
MZ`.#X#^-4`&#^CC&A`3(````@`^/+0(``+HW````*<*-A`3)````B50D",=$
M)`0`````B00DZ`W9__^)\,'H&(B$)``!``")\,'H$(B$)`$!``")\,'H"(B$
M)`(!``")\(B$)`,!``")V,'H&(B$)`0!``")V,'H$(B$)`4!``")V,'H"(B$
M)`8!``"-A"2L````B)PD!P$``(V\)(,```#H4MW__XN4)*P```"-="1PC9PD
MJP```(G1P>D8#[;!B$PD;XG1P>D0B$PD<(G1B%0D<HN4)+````#!Z0B(3"1Q
MB='!Z1B(3"1SB='!Z1"(3"1TB=&(5"1VBY0DM````,'I"(A,)'6)T<'I&(A,
M)'>)T<'I$(A,)'B)T8A4)'J+E"2X````P>D(B$PD>8G1P>D8B$PD>XG1P>D0
MB$PD?(G1B%0D?HN4)+P```#!Z0B(3"1]B='!Z1B(3"1_B='!Z1"(C"2`````
MB='!Z0B(C"2!````B)0D@@```.D&````#[8&@\8!B3PD@\<"B40D$,=$)`S^
MQ@0(QT0D"/_____'1"0$`0```.A;V?__.=]US\:$)*L`````C80D@P```,=$
M)!Q/QP0(B40D&(M$)"3'1"04YL4$",=$)`P;QP0(QT0D"/____^)1"00QT0D
M!`$```")+"3H#-G__^ER^O__BT0D*(M0!(72#X2`^?__B10DB50D*.C,UO__
MBU0D*(/X`P^&9_G__XUT`OR_%L<$"+D%````\Z8/A5'Y__^)T^E*^?__NC\`
M```IPHV$!,D```")5"0(QT0D!`````")!"3HX-;__XV$)*P```#HA-O__XV4
M),@```"Y#@```#'`B=?SJ^FP_?__@+PD#@$``$$/A<CZ__^`O"0/`0``0P^%
MNOK__X"\)!`!``!(#X6L^O__@+PD$0$``$4/A9[Z__^+="0HQT0D#`(```#'
M1"0$QO___\=$)`C_____B30DZ%'5__^-A"0,`0``QT0D""D```")1"0$B30D
MZ.;3__^-A"0,`0``QT0D'$_'!`CILO[__V:0Z&O4__^+1"0HBQCI,OC__U57
M5E.#["RA2$$%"(D$).A\U___C50D',9`70&X"<8$".C*Y?__A<!T"8`X,0^$
MK0(``.@(\?__H4A!!0B)!"3H2]?__\=$)`P+````QT0D"`$```#'1"0$2<<$
M"(D$).C[U/__A<`/A,L```"+0`R#/6A1!0@!BW@8#XZX````,?:[`0```.LQ
MC;0F`````(M%#(E$)`2A9%$%"(L$F(D$).@)T___A<!U?:%H404(@\,!@\8!
M.=A^<Z%(004(B00DZ,G6___'1"0,`````(ET)`B)?"0$B00DZ"'6__^%P'1%
MBRB+10@E``0@`#T`!```=)RA2$$%"(D$).B/UO__QT0D#`(```#'1"0(````
M`(EL)`2)!"3HL]/__^EQ____C;8`````H6A1!0B-4/\Y\@^$2`$``*%(004(
MB00DZ$O6___'1"0,!````,=$)`@!````QT0D!$['!`B)!"3H^]/__X7`B<-T
M-8M`#(LPH4A!!0B)!"3H$];__\=$)`A0QP0(B70D!(D$).@OT___BT,,BQCV
M0PI`#X4@`0``H4A!!0B)!"3HX]7__\=$)`P$````QT0D"`$```#'1"0$5<8$
M"(D$).B3T___A<")QG0ZC50D'+C7Q00(Z`_D__^%P(G##X25`0``BT8,BSBA
M2$$%"(D$).B3U?__B5PD"(E\)`2)!"3HL]+__Z%(004(B00DZ';5___&0%T`
MH4A!!0B)!"3H9=7__XU4)!S'@'`$````````N,[%!`CHK>/__X7`B<.C;%$%
M"`^$I@```,=$)`3``0``B00DZ,[3__^#^!%T#(U0`8/Z`0^'F0$``(/$+%M>
M7UW#D(UT)@"#^`$/CJ_^__^[`0```&:0H4A!!0B#PP&)!"3H\-3__XE\)`2)
M!"3H9-'__SD=:%$%"'_<Z7_^__^-M"8`````H4A!!0B)!"3HP]3__XE<)`2)
M!"3HM]/__^G"_O__9I"`>`$`#X1._?__C;8`````Z3[]__^-=@"A9%$%"(D$
M).B+\?__A<"C;%$%"`^$[@```(M&#(L]9%$%"(L8BT,()0`$(``]``0```^%
MH@```(M##(E\)`2)!"3H8='__XG'BT8,BQB+4PB!X@`$(`"!^@`$``!U4(M#
M#(E$)`BA9%$%"(E\)`R+`,<$)#3(!`B)1"0$Z(?2__^-M"8`````H611!0B+
M.(M&#(L8H4A!!0B)!"3H]]/__XGZB=CH;NC__^EF_O__H4A!!0B)!"3HW-/_
M_\=$)`P"````QT0D"`````")7"0$B00DZ`#1___KB*%(004(B00DZ+'3___'
M1"0,`@```,=$)`@`````B5PD!(D$).C5T/__Z3/____'!"00R`0(Z/31__^)
M1"0,H611!0B)7"0(BP#'!"1<R`0(B40D!.C5T?__D(UT)@!64X/L%(MT)"")
M-"3H'^S__P^V"(G#A,ET(8U0`>L+D`^V"H/"`83)=!&`^2]U\0^V"HG3@\(!
MA,EU[^B`[O__A<!T'87V=!F`/@!T%,=$)`0#QP0(B1PDZ!//__\YV'0&@\04
M6U[#@\04B?!;7ND=Y/__C;8`````C;PG`````(/L'*%(004(B00DZ-#2___'
M1"0$_____XD$).@@T/__H4A!!0B)!"3HL]+__\=$)`@`````QT0D!+"I!`B)
M!"3H:]+__X/$',-FD&:09I"04^CZU/__@<-:>P``@^P8BX,D`0``B40D#(M$
M)"B)1"0(BT0D)(E$)`2+1"0@B00DZ,O/__^#Q!A;PV:09I!FD%57,?]64^BU
MU/__@<,5>P``@^P<BVPD,(VSS/[__^C]S?__C8/(_O__*<;!_@*%]G0GC;8`
M````BT0D.(DL)(E$)`B+1"0TB40D!/^4N\C^__^#QP$Y]W7?@\0<6UY?7</K
M#9"0D)"0D)"0D)"0D)#SPP``4X/L".A#U/__@<.C>@``@\0(6\,#`````0`"
M`"5S+R5S`"]P<F]C+W-E;&8O97AE`'!E<FQX<VDN8P!$>6YA3&]A9&5R.CIB
M;V]T7T1Y;F%,;V%D97(`26YT97)N86QS.CI005(Z.D)/3U0`+W!R;V,O)6DO
M)7,`+@!005)?5$5-4`!005)?4%)/1TY!344`.@`O`%!%4DPU3$E"`%!%4DQ,
M24(`4$523#5/4%0`4$523$E/`%!!4E])3DE424%,25I%1`!005)?4U!!5TY%
M1`!005)?0TQ%04X`4$%27T1%0E5'`%!!4E]#04-(10!005)?05)'0P!005)?
M05)'5E\P`%!!4E]'3$]"04Q?1$5"54<`4$%27T=,3T)!3%]435!$25(`4$%2
M7U1-4$1)4@!005)?1TQ/0D%,7U1%35``4$%27T=,3T)!3%]#3$5!3@!005)?
M0TQ%04X]`#$`3$E"4$%42`!$64Q$7TQ)0E)!4EE?4$%42`!32$Q)0E]0051(
M`%5315(`4UE35$5-`"]T;7``5$5-4$1)4@!435``55-%4DY!344`)3`R>`!P
M87(M`"5S)7,E<R5S`'!A<FP`+G!A<@`E<R5S8V%C:&4M)7,E<P`E<R5S=&5M
M<"TE=25S`"5S)7-T96UP+25U+25U)7,`05)'5@`8`'!E<FP`+64`+2T``%]?
M14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@("`@`````"5S.B!C<F5A=&EO
M;B!O9B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I
M*0H``"5S.B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!I<R!U;G-A9F4@*'!L
M96%S92!R96UO=F4@:70@86YD(')E=')Y('EO=7(@;W!E<F%T:6]N*0H``%5N
M86)L92!T;R!C<F5A=&4@8V%C:&4@9&ER96-T;W)Y`````"5S.B!E>&5C=71I
M;VX@;V8@)7,@9F%I;&5D("AE<G)N;STE:2D*```E<SH@8W)E871I;VX@;V8@
M<')I=F%T92!C86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE
M:2D*`````",A+W5S<B]B:6XO<&5R;`IE=F%L("=E>&5C("]U<W(O8FEN+W!E
M<FP@("U3("0P("1[,2LB)$`B?2<*("`@(&EF(#`[(",@;F]T(')U;FYI;F<@
M=6YD97(@<V]M92!S:&5L;`H*<&%C:V%G92!?7W!A<E]P;#L*"B,@+2TM(%1H
M:7,@<V-R:7!T(&UU<W0@;F]T('5S92!A;GD@;6]D=6QE<R!A="!C;VUP:6QE
M('1I;64@+2TM"B,@=7-E('-T<FEC=#L*"B-L:6YE(#$U.`H*;7D@*"1P87)?
M=&5M<"P@)'!R;V=N86UE+"!`=&UP9FEL92D["D5.1"![(&EF("@D14Y6>U!!
M4E]#3$5!3GTI('L*("`@(')E<75I<F4@1FEL93HZ5&5M<#L*("`@(')E<75I
M<F4@1FEL93HZ0F%S96YA;64["B`@("!R97%U:7)E($9I;&4Z.E-P96,["B`@
M("!M>2`D=&]P9&ER(#T@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'!A<E]T
M96UP*3L*("`@(&]U=',H<7%[4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M
M<")]*3L*("`@($9I;&4Z.D9I;F0Z.F9I;F1D97!T:"AS=6(@>R`H("UD("D@
M/R!R;61I<B`Z('5N;&EN:R!]+"`D<&%R7W1E;7`I.PH@("`@<FUD:7(@)'!A
M<E]T96UP.PH@("`@(R!$;VXG="!R96UO=F4@=&]P9&ER(&)E8V%U<V4@=&AI
M<R!C875S97,@82!R86-E('=I=&@@;W1H97(@87!P<PH@("`@(R!T:&%T(&%R
M92!T<GEI;F<@=&\@<W1A<G0N"@H@("`@:68@*"UD("1P87)?=&5M<"`F)B`D
M7D\@;F4@)TU35VEN,S(G*2!["B`@("`@("`@(R!3;VUE=&AI;F<@=V5N="!W
M<F]N9R!U;FQI;FMI;F<@=&AE('1E;7!O<F%R>2!D:7)E8W1O<GDN("!4:&ES
M"B`@("`@("`@(R!T>7!I8V%L;'D@:&%P<&5N<R!O;B!P;&%T9F]R;7,@=&AA
M="!D:7-A;&QO=R!U;FQI;FMI;F<@<VAA<F5D"B`@("`@("`@(R!L:6)R87)I
M97,@86YD(&5X96-U=&%B;&5S('1H870@87)E(&EN('5S92X@56YL:6YK('=I
M=&@@82!B86-K9W)O=6YD"B`@("`@("`@(R!S:&5L;"!C;VUM86YD('-O('1H
M92!F:6QE<R!A<F4@;F\@;&]N9V5R(&EN('5S92!B>2!T:&ES('!R;V-E<W,N
M"B`@("`@("`@(R!$;VXG="!D;R!A;GET:&EN9R!O;B!7:6YD;W=S(&)E8V%U
M<V4@;W5R('!A<F5N="!P<F]C97-S('=I;&P*("`@("`@("`C('1A:V4@8V%R
M92!O9B!C;&5A;FEN9R!T:&EN9W,@=7`N"@H@("`@("`@(&UY("1T;7`@/2!N
M97<@1FEL93HZ5&5M<"@*("`@("`@("`@("`@5$5-4$Q!5$4@/3X@)W1M<%A8
M6%A8)RP*("`@("`@("`@("`@1$E2(#T^($9I;&4Z.D)A<V5N86UE.CID:7)N
M86UE*"1T;W!D:7(I+`H@("`@("`@("`@("!3549&25@@/3X@)RYC;60G+`H@
M("`@("`@("`@("!53DQ)3DL@/3X@,"P*("`@("`@("`I.PH*("`@("`@("!P
M<FEN="`D=&UP("(C(2]B:6XO<V@*>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@
M73L@9&\*("`@<FT@+7)F("<D<&%R7W1E;7`G"B`@(&EF(%L@7"$@+60@)R1P
M87)?=&5M<"<@73L@=&AE;@H@("`@("`@8G)E86L*("`@9FD*("`@<VQE97`@
M,0H@("!X/6!E>'!R(%PD>"`K(#%@"F1O;F4*<FT@)R(@+B`D=&UP+3YF:6QE
M;F%M92`N("(G"B(["B`@("`@("`@("`@(&-H;6]D(#`W,#`L)'1M<"T^9FEL
M96YA;64["B`@("`@("`@;7D@)&-M9"`]("1T;7`M/F9I;&5N86UE("X@)R`^
M+V1E=B]N=6QL(#(^)C$@)B<["B`@("`@("`@8VQO<V4@)'1M<#L*("`@("`@
M("!S>7-T96TH)&-M9"D["B`@("`@("`@;W5T<RAQ<2A3<&%W;F5D(&)A8VMG
M<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z("D*("`@("`@("`@
M("`@("X@)'1M<"T^9FEL96YA;64I.PH@("`@?0I]('T*"D)%1TE.('L*("`@
M($EN=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F:6YE9"`F26YT97)N86QS
M.CI005(Z.D)/3U0["@H@("`@979A;"!["@I?<&%R7VEN:71?96YV*"D["@II
M9B`H97AI<W1S("1%3E9[4$%27T%21U9?,'T@86YD("1%3E9[4$%27T%21U9?
M,'T@*2!["B`@("!`05)'5B`](&UA<"`D14Y6>R)005)?05)'5E\D7R)]+"`H
M,2`N+B`D14Y6>U!!4E]!4D=#?2`M(#$I.PH@("`@)#`@/2`D14Y6>U!!4E]!
M4D=67S!].PI]"F5L<V4@>PH@("`@9F]R("AK97ES("5%3E8I('L*("`@("`@
M("!D96QE=&4@)$5.5GLD7WT@:68@+UY005)?05)'5E\O.PH@("`@?0I]"@IM
M>2`D<75I970@/2`A)$5.5GM005)?1$5"54=].PH*(R!F:7@@)'!R;V=N86UE
M(&EF(&EN=F]K960@9G)O;2!0051("FUY("5#;VYF:6<@/2`H"B`@("!P871H
M7W-E<"`@("`]/B`H)%Y/(#U^("]>35-7:6XO(#\@)SLG(#H@)SHG*2P*("`@
M(%]E>&4@("`@("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\8WEG=VEN
M*2\@/R`G+F5X92<@.B`G)RDL"B`@("!?9&5L:6T@("`@("`]/B`H)%Y/(#U^
M("]>35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I+`HI.PH*7W-E=%]P<F]G;F%M
M92@I.PI?<V5T7W!A<E]T96UP*"D["@HC($UA9VEC('-T<FEN9R!C:&5C:VEN
M9R!A;F0@97AT<F%C=&EN9R!B=6YD;&5D(&UO9'5L97,@>WM["FUY("@D<W1A
M<G1?<&]S+"`D9&%T85]P;W,I.PI["B`@("!L;V-A;"`D4TE'>U]?5T%23E]?
M?2`]('-U8B![?3L*"B`@("`C($-H96-K(&9I;&4@='EP92P@9V5T('-T87)T
M(&]F(&1A=&$@<V5C=&EO;B![>WL*("`@(&]P96X@7T9(+"`G/"<L("1P<F]G
M;F%M92!O<B!L87-T.PH@("`@8FEN;6]D92A?1D@I.PH*("`@(&UY("1B=68[
M"B`@("!S965K(%]&2"P@+3@L(#(["B`@("!R96%D(%]&2"P@)&)U9BP@.#L*
M("`@(&QA<W0@=6YL97-S("1B=68@97$@(EQN4$%2+G!M7&XB.PH*("`@('-E
M96L@7T9(+"`M,3(L(#(["B`@("!R96%D(%]&2"P@)&)U9BP@-#L*("`@('-E
M96L@7T9(+"`M,3(@+2!U;G!A8VLH(DXB+"`D8G5F*2P@,CL*("`@(')E860@
M7T9(+"`D8G5F+"`T.PH*("`@("1D871A7W!O<R`]("AT96QL(%]&2"D@+2`T
M.PH@("`@(R!]?7T*"B`@("`C($5X=')A8W1I;F<@96%C:"!F:6QE(&EN=&\@
M;65M;W)Y('M[>PH@("`@;7D@)7)E<75I<F5?;&ES=#L*("`@('=H:6QE("@D
M8G5F(&5Q(")&24Q%(BD@>PH@("`@("`@(')E860@7T9(+"`D8G5F+"`T.PH@
M("`@("`@(')E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*"B`@
M("`@("`@;7D@)&9U;&QN86UE(#T@)&)U9CL*("`@("`@("!O=71S*'%Q*%5N
M<&%C:VEN9R!F:6QE("(D9G5L;&YA;64B+BXN*2D["B`@("`@("`@;7D@)&-R
M8R`]("@@)&9U;&QN86UE(#U^('-\7BA;82UF7&1=>SA]*2]\?"`I(#\@)#$@
M.B!U;F1E9CL*("`@("`@("!M>2`H)&)A<V5N86UE+"`D97AT*2`]("@D8G5F
M(#U^(&U\*#\Z+BHO*3\H+BHI*%PN+BHI?"D["@H@("`@("`@(')E860@7T9(
M+"`D8G5F+"`T.PH@("`@("`@(')E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB
M+"`D8G5F*3L*"B`@("`@("`@:68@*&1E9FEN960H)&5X="D@86YD("1E>'0@
M(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2!["B`@("`@("`@("`@(&UY("@D
M;W5T+"`D9FEL96YA;64I(#T@7W1E;7!F:6QE*"1E>'0L("1C<F,I.PH@("`@
M("`@("`@("!I9B`H)&]U="D@>PH@("`@("`@("`@("`@("`@8FEN;6]D92@D
M;W5T*3L*("`@("`@("`@("`@("`@('!R:6YT("1O=70@)&)U9CL*("`@("`@
M("`@("`@("`@(&-L;W-E("1O=70["B`@("`@("`@("`@("`@("!C:&UO9"`P
M-S4U+"`D9FEL96YA;64["B`@("`@("`@("`@('T*("`@("`@("`@("`@)%!!
M4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65](#T@)&9I;&5N86UE.PH@
M("`@("`@("`@("`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F:6QE;F%M97T@
M/2`D9G5L;&YA;64["B`@("`@("`@?0H@("`@("`@(&5L<VEF("@@)&9U;&QN
M86UE(#U^(&U\7B\_<VAL:6(O?"!A;F0@9&5F:6YE9"`D14Y6>U!!4E]414U0
M?2`I('L*("`@("`@("`@("`@(R!S:&]U;&0@8F4@;6]V960@=&\@7W1E;7!F
M:6QE*"D*("`@("`@("`@("`@;7D@)&9I;&5N86UE(#T@(B1%3E9[4$%27U1%
M35!]+R1B87-E;F%M921E>'0B.PH@("`@("`@("`@("!O=71S*")32$Q)0CH@
M)&9I;&5N86UE7&XB*3L*("`@("`@("`@("`@;W!E;B!M>2`D;W5T+"`G/B<L
M("1F:6QE;F%M92!O<B!D:64@)"$["B`@("`@("`@("`@(&)I;FUO9&4H)&]U
M="D["B`@("`@("`@("`@('!R:6YT("1O=70@)&)U9CL*("`@("`@("`@("`@
M8VQO<V4@)&]U=#L*("`@("`@("!]"B`@("`@("`@96QS92!["B`@("`@("`@
M("`@("1R97%U:7)E7VQI<W1[)&9U;&QN86UE?2`]"B`@("`@("`@("`@("10
M05(Z.DAE879Y.CI-;V1U;&5#86-H97LD9G5L;&YA;65](#T@>PH@("`@("`@
M("`@("`@("`@8G5F(#T^("1B=68L"B`@("`@("`@("`@("`@("!C<F,@/3X@
M)&-R8RP*("`@("`@("`@("`@("`@(&YA;64@/3X@)&9U;&QN86UE+`H@("`@
M("`@("`@("!].PH@("`@("`@('T*("`@("`@("!R96%D(%]&2"P@)&)U9BP@
M-#L*("`@('T*("`@(",@?7U]"@H@("`@;&]C86P@0$E.0R`]("AS=6(@>PH@
M("`@("`@(&UY("@D<V5L9BP@)&UO9'5L92D@/2!`7SL*"B`@("`@("`@<F5T
M=7)N(&EF(')E9B`D;6]D=6QE(&]R("$D;6]D=6QE.PH*("`@("`@("!M>2`D
M9FEL96YA;64@/2!D96QE=&4@)')E<75I<F5?;&ES='LD;6]D=6QE?2!\?"!D
M;R!["B`@("`@("`@("`@(&UY("1K97D["B`@("`@("`@("`@(&9O<F5A8V@@
M*&ME>7,@)7)E<75I<F5?;&ES="D@>PH@("`@("`@("`@("`@("`@;F5X="!U
M;FQE<W,@+UQ1)&UO9'5L95Q%)"\["B`@("`@("`@("`@("`@("`D:V5Y(#T@
M)%\[(&QA<W0["B`@("`@("`@("`@('T*("`@("`@("`@("`@9&5L971E("1R
M97%U:7)E7VQI<W1[)&ME>7T@:68@9&5F:6YE9"@D:V5Y*3L*("`@("`@("!]
M(&]R(')E='5R;CL*"B`@("`@("`@)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R
M+R1F:6QE;F%M92\D;6]D=6QE(CL*"B`@("`@("`@:68@*"1%3E9[4$%27T-,
M14%.?2!A;F0@9&5F:6YE9"@F24\Z.D9I;&4Z.FYE=RDI('L*("`@("`@("`@
M("`@;7D@)&9H(#T@24\Z.D9I;&4M/FYE=U]T;7!F:6QE(&]R(&1I92`D(3L*
M("`@("`@("`@("`@8FEN;6]D92@D9F@I.PH@("`@("`@("`@("!P<FEN="`D
M9F@@)&9I;&5N86UE+3Y[8G5F?3L*("`@("`@("`@("`@<V5E:R@D9F@L(#`L
M(#`I.PH@("`@("`@("`@("!R971U<FX@)&9H.PH@("`@("`@('T*("`@("`@
M("!E;'-E('L*("`@("`@("`@("`@;7D@*"1O=70L("1N86UE*2`](%]T96UP
M9FEL92@G+G!M)RP@)&9I;&5N86UE+3Y[8W)C?2D["B`@("`@("`@("`@(&EF
M("@D;W5T*2!["B`@("`@("`@("`@("`@("!B:6YM;V1E*"1O=70I.PH@("`@
M("`@("`@("`@("`@<')I;G0@)&]U="`D9FEL96YA;64M/GMB=69].PH@("`@
M("`@("`@("`@("`@8VQO<V4@)&]U=#L*("`@("`@("`@("`@?0H@("`@("`@
M("`@("!O<&5N(&UY("1F:"P@)SPG+"`D;F%M92!O<B!D:64@)"$["B`@("`@
M("`@("`@(&)I;FUO9&4H)&9H*3L*("`@("`@("`@("`@<F5T=7)N("1F:#L*
M("`@("`@("!]"@H@("`@("`@(&1I92`B0F]O='-T<F%P<&EN9R!F86EL960Z
M(&-A;FYO="!F:6YD("1M;V1U;&4A7&XB.PH@("`@?2P@0$E.0RD["@H@("`@
M(R!.;W<@;&]A9"!A;&P@8G5N9&QE9"!F:6QE<R![>WL*"B`@("`C(&EN:71I
M86QI>F4@<VAA<F5D(&]B:F5C="!P<F]C97-S:6YG"B`@("!R97%U:7)E(%A3
M3&]A9&5R.PH@("`@<F5Q=6ER92!005(Z.DAE879Y.PH@("`@<F5Q=6ER92!#
M87)P.CI(96%V>3L*("`@(')E<75I<F4@17AP;W)T97(Z.DAE879Y.PH@("`@
M4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PH*("`@(",@;F]W(&QE
M="=S('1R>2!G971T:6YG(&AE;'!E<B!M;V1U;&5S(&9R;VT@=VET:&EN"B`@
M("!R97%U:7)E($E/.CI&:6QE.PH*("`@(",@;&]A9"!R97-T(&]F('1H92!G
M<F]U<"!I;@H@("`@=VAI;&4@*&UY("1F:6QE;F%M92`]("AS;W)T(&ME>7,@
M)7)E<75I<F5?;&ES="E;,%TI('L*("`@("`@("`C;&]C86P@)$E.0WLG0W=D
M+G!M)WT@/2!?7T9)3$5?7R!I9B`D7D\@;F4@)TU35VEN,S(G.PH@("`@("`@
M('5N;&5S<R`H)$E.0WLD9FEL96YA;65](&]R("1F:6QE;F%M92`]?B`O0E-$
M4$%.+RD@>PH@("`@("`@("`@("`C(')E<75I<F4@;6]D=6QE<RP@9&\@;W1H
M97(@97AE8W5T86)L92!F:6QE<PH@("`@("`@("`@("!I9B`H)&9I;&5N86UE
M(#U^("]<+G!M8S\D+VDI('L*("`@("`@("`@("`@("`@(')E<75I<F4@)&9I
M;&5N86UE.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<V4@>PH@("`@
M("`@("`@("`@("`@(R!3:VEP($%C=&EV95-T871E)W,@<VET96-U<W1O;6EZ
M92YP;"!F:6QE.@H@("`@("`@("`@("`@("`@9&\@)&9I;&5N86UE('5N;&5S
M<R`D9FEL96YA;64@/7X@+W-I=&5C=7-T;VUI>F5<+G!L)"\["B`@("`@("`@
M("`@('T*("`@("`@("!]"B`@("`@("`@9&5L971E("1R97%U:7)E7VQI<W1[
M)&9I;&5N86UE?3L*("`@('T*"B`@("`C('U]?0H*("`@(&QA<W0@=6YL97-S
M("1B=68@97$@(E!+7#`P,UPP,#0B.PH@("`@)'-T87)T7W!O<R`]("AT96QL
M(%]&2"D@+2`T.PI]"B,@?7U]"@HC($%R9W5M96YT('!R;V-E<W-I;F<@>WM[
M"FUY($!P87)?87)G<SL*;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@)&-A
M8VAE7VYA;64I.PH*9&5L971E("1%3E9[4$%27T%04%]2155317T[(",@<V%N
M:71I>F4@*%)%55-%(&UA>2!B92!A('-E8W5R:71Y('!R;V)L96TI"@HD<75I
M970@/2`P('5N;&5S<R`D14Y6>U!!4E]$14)51WT["B,@1&]N)W0@<W=A;&QO
M=R!A<F=U;65N=',@9F]R(&-O;7!I;&5D(&5X96-U=&%B;&5S('=I=&AO=70@
M+2UP87(M;W!T:6]N<PII9B`H(21S=&%R=%]P;W,@;W(@*"1!4D=66S!=(&5Q
M("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*("`@(&UY("5D:7-T7V-M
M9"`]('%W*`H@("`@("`@('`@("!B;&EB7W1O7W!A<@H@("`@("`@(&D@("!I
M;G-T86QL7W!A<@H@("`@("`@('4@("!U;FEN<W1A;&Q?<&%R"B`@("`@("`@
M<R`@('-I9VY?<&%R"B`@("`@("`@=B`@('9E<FEF>5]P87(*("`@("D["@H@
M("`@(R!I9B!T:&4@87!P(&ES(&EN=F]K960@87,@(F%P<&YA;64@+2UP87(M
M;W!T:6]N<R`M+7)E=7-E(%!23T=204T@0%!23T=?05)'5B(L"B`@("`C('5S
M92!T:&4@87!P('1O(')U;B!T:&4@9VEV96X@<&5R;"!C;V1E(&EN<W1E860@
M;V8@86YY=&AI;F<@9G)O;2!T:&4*("`@(",@87!P(&ET<V5L9B`H8G5T('-T
M:6QL('-E="!U<"!T:&4@;F]R;6%L(&%P<"!E;G9I<F]N;65N="!A;F0@0$E.
M0RD*("`@(&EF("A`05)'5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U<V4G*2![
M"B`@("`@("`@<VAI9G0@0$%21U8["B`@("`@("`@)$5.5GM005)?05!07U)%
M55-%?2`]('-H:69T($!!4D=6.PH@("`@?0H@("`@96QS92![(",@;F]R;6%L
M('!A<FP@8F5H879I;W5R"@H@("`@("`@(&UY($!A9&1?=&]?:6YC.PH@("`@
M("`@('=H:6QE("A`05)'5BD@>PH@("`@("`@("`@("`D05)'5ELP72`]?B`O
M7BTH6T%)34]"3&)Q<&EU<U1V72DH+BHI+R!O<B!L87-T.PH*("`@("`@("`@
M("`@:68@*"0Q(&5Q("=))RD@>PH@("`@("`@("`@("`@("`@<'5S:"!`861D
M7W1O7VEN8RP@)#(["B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS:68@
M*"0Q(&5Q("=-)RD@>PH@("`@("`@("`@("`@("`@979A;"`B=7-E("0R(CL*
M("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-I9B`H)#$@97$@)T$G*2![
M"B`@("`@("`@("`@("`@("!U;G-H:69T($!P87)?87)G<RP@)#(["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@96QS:68@*"0Q(&5Q("=/)RD@>PH@("`@
M("`@("`@("`@("`@)&]U="`]("0R.PH@("`@("`@("`@("!]"B`@("`@("`@
M("`@(&5L<VEF("@D,2!E<2`G8B<I('L*("`@("`@("`@("`@("`@("1B=6YD
M;&4@/2`G<VET92<["B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS:68@
M*"0Q(&5Q("=")RD@>PH@("`@("`@("`@("`@("`@)&)U;F1L92`]("=A;&PG
M.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<VEF("@D,2!E<2`G<2<I
M('L*("`@("`@("`@("`@("`@("1Q=6EE="`](#$["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@96QS:68@*"0Q(&5Q("=,)RD@>PH@("`@("`@("`@("`@
M("`@;W!E;B`D;&]G9F@L("(^/B(L("0R(&]R(&1I92`B6%A8.B!#86YN;W0@
M;W!E;B!L;V<Z("0A(CL*("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-I
M9B`H)#$@97$@)U0G*2!["B`@("`@("`@("`@("`@("`D8V%C:&5?;F%M92`]
M("0R.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!S:&EF="A`05)'5BD[
M"@H@("`@("`@("`@("!I9B`H;7D@)&-M9"`]("1D:7-T7V-M9'LD,7TI('L*
M("`@("`@("`@("`@("`@(&1E;&5T92`D14Y6>R=005)?5$5-4"=].PH@("`@
M("`@("`@("`@("`@:6YI=%]I;F,H*3L*("`@("`@("`@("`@("`@(')E<75I
M<F4@4$%2.CI$:7-T.PH@("`@("`@("`@("`@("`@)GLB4$%2.CI$:7-T.CHD
M8VUD(GTH*2!U;FQE<W,@0$%21U8["B`@("`@("`@("`@("`@("`F>R)005(Z
M.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6.PH@("`@("`@("`@("`@("`@
M97AI=#L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@=6YS:&EF
M="!`24Y#+"!`861D7W1O7VEN8SL*("`@('T*?0H*(R!86%@@+2T@861D("TM
M<&%R+61E8G5G('-U<'!O<G0A"@HC('U]?0H*(R!/=71P=70@;6]D92`H+4\I
M(&AA;F1L:6YG('M[>PII9B`H)&]U="D@>PH@("`@>PH@("`@("`@("-L;V-A
M;"`D24Y#>R=#=V0N<&TG?2`](%]?1DE,15]?(&EF("1>3R!N92`G35-7:6XS
M,B<["B`@("`@("`@<F5Q=6ER92!)3SHZ1FEL93L*("`@("`@("!R97%U:7)E
M($%R8VAI=F4Z.EII<#L*("`@('T*"B`@("!M>2`D<&%R(#T@<VAI9G0H0$%2
M1U8I.PH@("`@;7D@)'II<#L*"@H@("`@:68@*&1E9FEN960@)'!A<BD@>PH@
M("`@("`@(&]P96X@;7D@)&9H+"`G/"<L("1P87(@;W(@9&EE(")#86YN;W0@
M9FEN9"`G)'!A<B<Z("0A(CL*("`@("`@("!B:6YM;V1E*"1F:"D["B`@("`@
M("`@8FQE<W,H)&9H+"`G24\Z.D9I;&4G*3L*"B`@("`@("`@)'II<"`]($%R
M8VAI=F4Z.EII<"T^;F5W.PH@("`@("`@("@@)'II<"T^<F5A9$9R;VU&:6QE
M2&%N9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I("D*
M("`@("`@("`@("`@;W(@9&EE(")296%D("<D<&%R)R!E<G)O<CH@)"$B.PH@
M("`@?0H*"B`@("!M>2`E96YV(#T@9&\@>PH@("`@("`@(&EF("@D>FEP(&%N
M9"!M>2`D;65T82`]("1Z:7`M/F-O;G1E;G1S*"=-151!+GEM;"<I*2!["B`@
M("`@("`@("`@("1M971A(#U^(',O+BI><&%R.B0O+VUS.PH@("`@("`@("`@
M("`D;65T82`]?B!S+UY<4RXJ+R]M<SL*("`@("`@("`@("`@)&UE=&$@/7X@
M+UX@("A;7CI=*RDZ("@N*RDD+VUG.PH@("`@("`@('T*("`@('T["@H@("`@
M(R!/<&5N(&EN<'5T(&%N9"!O=71P=70@9FEL97,@>WM["B`@("!L;V-A;"`D
M+R`](%PT.PH*("`@(&EF("AD969I;F5D("1P87(I('L*("`@("`@("!O<&5N
M(%!!4BP@)SPG+"`D<&%R(&]R(&1I92`B)"$Z("1P87(B.PH@("`@("`@(&)I
M;FUO9&4H4$%2*3L*("`@("`@("!D:64@(B1P87(@:7,@;F]T(&$@4$%2(&9I
M;&4B('5N;&5S<R`\4$%2/B!E<2`B4$M<,#`S7#`P-"(["B`@("!]"@H@("`@
M0W)E871E4&%T:"@D;W5T*2`["B`@("`*("`@(&UY("1F:"`]($E/.CI&:6QE
M+3YN97<H"B`@("`@("`@)&]U="P*("`@("`@("!)3SHZ1FEL93HZ3U]#4D5!
M5"@I('P@24\Z.D9I;&4Z.D]?5U)/3DQ9*"D@?"!)3SHZ1FEL93HZ3U]44E5.
M0R@I+`H@("`@("`@(#`W-S<L"B`@("`I(&]R(&1I92`D(3L*("`@(&)I;FUO
M9&4H)&9H*3L*"B`@("`D+R`]("AD969I;F5D("1D871A7W!O<RD@/R!<)&1A
M=&%?<&]S(#H@=6YD968["B`@("!S965K(%]&2"P@,"P@,#L*("`@(&UY("1L
M;V%D97(@/2!S8V%L87(@/%]&2#X["B`@("!I9B`H(21%3E9[4$%27U9%4D)!
M5$E-?2!A;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`<F5M*2\I('L*("`@("`@
M("!R97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*("`@("`@("!005(Z
M.D9I;'1E<CHZ4&]D4W1R:7`M/FYE=RT^87!P;'DH7"1L;V%D97(L("0P*0H@
M("`@?0H@("`@9F]R96%C:"!M>2`D:V5Y("AS;W)T(&ME>7,@)65N=BD@>PH@
M("`@("`@(&UY("1V86P@/2`D96YV>R1K97E](&]R(&YE>'0["B`@("`@("`@
M)'9A;"`](&5V86P@)'9A;"!I9B`D=F%L(#U^("]>6R<B72\["B`@("`@("`@
M;7D@)&UA9VEC(#T@(E]?14Y67U!!4E\B("X@=6,H)&ME>2D@+B`B7U\B.PH@
M("`@("`@(&UY("1S970@/2`B4$%27R(@+B!U8R@D:V5Y*2`N("(])'9A;"([
M"B`@("`@("`@)&QO861E<B`]?B!S>R1M86=I8R@@*RE]>PH@("`@("`@("`@
M("`D;6%G:6,@+B`D<V5T("X@*"<@)R!X("AL96YG=&@H)#$I("T@;&5N9W1H
M*"1S970I*2D*("`@("`@("!]96<["B`@("!]"B`@("`D9F@M/G!R:6YT*"1L
M;V%D97(I.PH@("`@)"\@/2!U;F1E9CL*("`@(",@?7U]"@H@("`@(R!7<FET
M92!B=6YD;&5D(&UO9'5L97,@>WM["B`@("!I9B`H)&)U;F1L92D@>PH@("`@
M("`@(')E<75I<F4@4$%2.CI(96%V>3L*("`@("`@("!005(Z.DAE879Y.CI?
M:6YI=%]D>6YA;&]A9&5R*"D["B`@("`@("`@:6YI=%]I;F,H*3L*"B`@("`@
M("`@<F5Q=6ER95]M;V1U;&5S*"D["@H@("`@("`@(&UY($!I;F,@/2!S;W)T
M('L*("`@("`@("`@("`@;&5N9W1H*"1B*2`\/3X@;&5N9W1H*"1A*0H@("`@
M("`@('T@9W)E<"!["B`@("`@("`@("`@("$O0E-$4$%.+PH@("`@("`@('T@
M9W)E<"!["B`@("`@("`@("`@("@D8G5N9&QE(&YE("=S:71E)RD@;W(*("`@
M("`@("`@("`@*"1?(&YE("1#;VYF:6<Z.D-O;F9I9WMA<F-H;&EB97AP?2!A
M;F0*("`@("`@("`@("`@("1?(&YE("1#;VYF:6<Z.D-O;F9I9WMP<FEV;&EB
M97AP?2D["B`@("`@("`@?2!`24Y#.PH*("`@("`@("`C($9I;&4@97AI<W1S
M('1E<W0@861D960@=&\@9FEX(%)4(",T,3<Y,#H*("`@("`@("`C($9U;FYY
M+"!N;VXM97AI<W1I;F<@96YT<GD@:6X@7SPN+BXN875T;R]#;VUP<F5S<R]2
M87<O6FQI8B]A=71O<W!L:70N:7@N"B`@("`@("`@(R!4:&ES(&ES(&$@8F%N
M9"UA:60@9FEX('=I=&@@;F\@9&5E<&5R(&=R87-P(&]F('1H92!I<W-U92X*
M("`@("`@("`C(%-O;65B;V1Y('!L96%S92!G;R!T:')O=6=H('1H92!P86EN
M(&]F('5N9&5R<W1A;F1I;F<@=VAA="=S(&AA<'!E;FEN9RP*("`@("`@("`C
M($D@9F%I;&5D+B`M+2!3=&5F9F5N"B`@("`@("`@;7D@)69I;&5S.PH@("`@
M("`@("]>7SPH+BLI)"\@86YD("UE("0Q(&%N9"`D9FEL97-[)#%]*RL@9F]R
M(&ME>7,@)3HZ.PH@("`@("`@("1F:6QE<WLD7WTK*R!F;W(@=F%L=65S("5)
M3D,["@H@("`@("`@(&UY("1L:6)?97AT(#T@)$-O;F9I9SHZ0V]N9FEG>VQI
M8E]E>'1].PH@("`@("`@(&UY("5W<FET=&5N.PH*("`@("`@("!F;W)E86-H
M("AS;W)T(&ME>7,@)69I;&5S*2!["B`@("`@("`@("`@(&UY("@D;F%M92P@
M)&9I;&4I.PH*("`@("`@("`@("`@9F]R96%C:"!M>2`D9&ER("A`:6YC*2![
M"B`@("`@("`@("`@("`@("!I9B`H)&YA;64@/2`D4$%2.CI(96%V>3HZ1G5L
M;$-A8VAE>R1??2D@>PH@("`@("`@("`@("`@("`@("`@("1F:6QE(#T@)%\[
M"B`@("`@("`@("`@("`@("`@("`@;&%S=#L*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@(&5L<VEF("@O7BA<421D:7)<15PO*"XJ6UY#8UTI
M*5Q:+VDI('L*("`@("`@("`@("`@("`@("`@("`H)&9I;&4L("1N86UE*2`]
M("@D,2P@)#(I.PH@("`@("`@("`@("`@("`@("`@(&QA<W0["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("!E;'-I9B`H;2%>+VQO861E<B];
M7B]=*R\H+BI;7D-C72E<6B$I('L*("`@("`@("`@("`@("`@("`@("!I9B`H
M;7D@)')E9B`]("1005(Z.DAE879Y.CI-;V1U;&5#86-H97LD,7TI('L*("`@
M("`@("`@("`@("`@("`@("`@("`@*"1F:6QE+"`D;F%M92D@/2`H)')E9BP@
M)#$I.PH@("`@("`@("`@("`@("`@("`@("`@("!L87-T.PH@("`@("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!E;'-I9B`H+68@(B1D
M:7(O)#$B*2!["B`@("`@("`@("`@("`@("`@("`@("`@("@D9FEL92P@)&YA
M;64I(#T@*"(D9&ER+R0Q(BP@)#$I.PH@("`@("`@("`@("`@("`@("`@("`@
M("!L87-T.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@?0H*("`@("`@("`@("`@;F5X="!U;FQE<W,@9&5F
M:6YE9"`D;F%M92!A;F0@;F]T("1W<FET=&5N>R1N86UE?2LK.PH@("`@("`@
M("`@("!N97AT(&EF("%R968H)&9I;&4I(&%N9"`D9FEL92`]?B`O7"Y<421L
M:6)?97AT7$4D+SL*("`@("`@("`@("`@;W5T<R@@:F]I;B`B(BP*("`@("`@
M("`@("`@("`@('%Q*%!A8VMI;F<@(BDL(')E9B`D9FEL92`_("1F:6QE+3Y[
M;F%M97T@.B`D9FEL92P*("`@("`@("`@("`@("`@('%Q*"(N+BXI"B`@("`@
M("`@("`@("D["@H@("`@("`@("`@("!M>2`D8V]N=&5N=#L*("`@("`@("`@
M("`@:68@*')E9B@D9FEL92DI('L*("`@("`@("`@("`@("`@("1C;VYT96YT
M(#T@)&9I;&4M/GMB=69].PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L
M<V4@>PH@("`@("`@("`@("`@("`@;W!E;B!&24Q%+"`G/"<L("1F:6QE(&]R
M(&1I92`B0V%N)W0@;W!E;B`D9FEL93H@)"$B.PH@("`@("`@("`@("`@("`@
M8FEN;6]D92A&24Q%*3L*("`@("`@("`@("`@("`@("1C;VYT96YT(#T@/$9)
M3$4^.PH@("`@("`@("`@("`@("`@8VQO<V4@1DE,13L*"B`@("`@("`@("`@
M("`@("!005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/FYE=RT^87!P;'DH7"1C;VYT
M96YT+"`D9FEL92D*("`@("`@("`@("`@("`@("`@("!I9B`A)$5.5GM005)?
M5D520D%424U](&%N9"`D;F%M92`]?B`O7"XH/SIP;7QI>'QA;"DD+VD["@H@
M("`@("`@("`@("`@("`@4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N="T^;F5W
M+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE+"`D;F%M92D["B`@("`@("`@("`@
M('T*"B`@("`@("`@("`@(&]U=',H<7$H5W)I='1E;B!A<R`B)&YA;64B*2D[
M"B`@("`@("`@("`@("1F:"T^<')I;G0H(D9)3$4B*3L*("`@("`@("`@("`@
M)&9H+3YP<FEN="AP86-K*"=.)RP@;&5N9W1H*"1N86UE*2`K(#DI*3L*("`@
M("`@("`@("`@)&9H+3YP<FEN="AS<')I;G1F*`H@("`@("`@("`@("`@("`@
M(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S,B@D8V]N=&5N
M="DL("1N86UE"B`@("`@("`@("`@("DI.PH@("`@("`@("`@("`D9F@M/G!R
M:6YT*'!A8VLH)TXG+"!L96YG=&@H)&-O;G1E;G0I*2D["B`@("`@("`@("`@
M("1F:"T^<')I;G0H)&-O;G1E;G0I.PH@("`@("`@('T*("`@('T*("`@(",@
M?7U]"@H@("`@(R!.;W<@=W)I=&4@;W5T('1H92!005(@86YD(&UA9VEC('-T
M<FEN9W,@>WM["B`@("`D>FEP+3YW<FET951O1FEL94AA;F1L92@D9F@I(&EF
M("1Z:7`["@H@("`@)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA;64L
M(#`L(#0P.PH@("`@:68@*"$D8V%C:&5?;F%M92!A;F0@;7D@)&UT:6UE(#T@
M*'-T870H)&]U="DI6SE=*2!["B`@("`@("`@;7D@)&-T>"`](&5V86P@>R!R
M97%U:7)E($1I9V5S=#HZ4TA!.R!$:6=E<W0Z.E-(02T^;F5W*#$I('T*("`@
M("`@("`@("`@?'P@979A;"![(')E<75I<F4@1&EG97-T.CI32$$Q.R!$:6=E
M<W0Z.E-(03$M/FYE=R!]"B`@("`@("`@("`@('Q\(&5V86P@>R!R97%U:7)E
M($1I9V5S=#HZ340U.R!$:6=E<W0Z.DU$-2T^;F5W('T["@H@("`@("`@(",@
M5V]R:V%R;W5N9"!F;W(@8G5G(&EN($1I9V5S=#HZ4TA!(#4N,S@@86YD(#4N
M,SD*("`@("`@("!M>2`D<VAA7W9E<G-I;VX@/2!E=F%L('L@)$1I9V5S=#HZ
M4TA!.CI615)324].('T@?'P@,#L*("`@("`@("!I9B`H)'-H85]V97)S:6]N
M(&5Q("<U+C,X)R!O<B`D<VAA7W9E<G-I;VX@97$@)S4N,SDG*2!["B`@("`@
M("`@("`@("1C='@M/F%D9&9I;&4H)&]U="P@(F(B*2!I9B`H)&-T>"D["B`@
M("`@("`@?0H@("`@("`@(&5L<V4@>PH@("`@("`@("`@("!I9B`H)&-T>"!A
M;F0@;W!E;BAM>2`D9F@L("(\)&]U="(I*2!["B`@("`@("`@("`@("`@("!B
M:6YM;V1E*"1F:"D["B`@("`@("`@("`@("`@("`D8W1X+3YA9&1F:6QE*"1F
M:"D["B`@("`@("`@("`@("`@("!C;&]S92@D9F@I.PH@("`@("`@("`@("!]
M"B`@("`@("`@?0H*("`@("`@("`D8V%C:&5?;F%M92`]("1C='@@/R`D8W1X
M+3YH97AD:6=E<W0@.B`D;71I;64["B`@("!]"B`@("`D8V%C:&5?;F%M92`N
M/2`B7#`B('@@*#0Q("T@;&5N9W1H("1C86-H95]N86UE*3L*("`@("1C86-H
M95]N86UE("X](")#04-(12(["B`@("`D9F@M/G!R:6YT*"1C86-H95]N86UE
M*3L*("`@("1F:"T^<')I;G0H<&%C:R@G3B<L("1F:"T^=&5L;"`M(&QE;F=T
M:"@D;&]A9&5R*2DI.PH@("`@)&9H+3YP<FEN="@B7&Y005(N<&U<;B(I.PH@
M("`@)&9H+3YC;&]S93L*("`@(&-H;6]D(#`W-34L("1O=70["B`@("`C('U]
M?0H*("`@(&5X:70["GT*(R!]?7T*"B,@4')E<&%R92`D<')O9VYA;64@:6YT
M;R!005(@9FEL92!C86-H92![>WL*>PH@("`@;&%S="!U;FQE<W,@9&5F:6YE
M9"`D<W1A<G1?<&]S.PH*("`@(%]F:7A?<')O9VYA;64H*3L*"B`@("`C($YO
M=R!L;V%D('1H92!005(@9FEL92!A;F0@<'5T(&ET(&EN=&\@4$%2.CI,:6)#
M86-H92![>WL*("`@(')E<75I<F4@4$%2.PH@("`@4$%2.CI(96%V>3HZ7VEN
M:71?9'EN86QO861E<B@I.PH*"B`@("!["B`@("`@("`@(VQO8V%L("1)3D-[
M)T-W9"YP;2=](#T@7U]&24Q%7U\@:68@)%Y/(&YE("=-4U=I;C,R)SL*("`@
M("`@("!R97%U:7)E($9I;&4Z.D9I;F0["B`@("`@("`@<F5Q=6ER92!!<F-H
M:79E.CI::7`["B`@("!]"B`@("!M>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN
M97<["B`@("!M>2`D9F@@/2!)3SHZ1FEL92T^;F5W.PH@("`@)&9H+3YF9&]P
M96XH9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE("(D(3H@)$`B.PH@("`@)'II
M<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H
M:79E.CI::7`Z.D%:7T]+*"D@;W(@9&EE("(D(3H@)$`B.PH*("`@('!U<V@@
M0%!!4CHZ3&EB0V%C:&4L("1Z:7`["B`@("`D4$%2.CI,:6)#86-H97LD<')O
M9VYA;65](#T@)'II<#L*"B`@("`D<75I970@/2`A)$5.5GM005)?1$5"54=]
M.PH@("`@;W5T<RAQ<2A<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM005)?5$5-
M4'TB*2D["@H@("`@:68@*&1E9FEN960@)$5.5GM005)?5$5-4'TI('L@(R!S
M:&]U;&0@8F4@<V5T(&%T('1H:7,@<&]I;G0A"B`@("`@("`@9F]R96%C:"!M
M>2`D;65M8F5R("@@)'II<"T^;65M8F5R<R`I('L*("`@("`@("`@("`@;F5X
M="!I9B`D;65M8F5R+3YI<T1I<F5C=&]R>3L*("`@("`@("`@("`@;7D@)&UE
M;6)E<E]N86UE(#T@)&UE;6)E<BT^9FEL94YA;64["B`@("`@("`@("`@(&YE
M>'0@=6YL97-S("1M96UB97)?;F%M92`]?B!M>PH@("`@("`@("`@("`@("`@
M7@H@("`@("`@("`@("`@("`@+S]S:&QI8B\*("`@("`@("`@("`@("`@("@_
M.B1#;VYF:6<Z.D-O;F9I9WMV97)S:6]N?2\I/PH@("`@("`@("`@("`@("`@
M*#\Z)$-O;F9I9SHZ0V]N9FEG>V%R8VAN86UE?2\I/PH@("`@("`@("`@("`@
M("`@*%M>+UTK*0H@("`@("`@("`@("`@("`@)`H@("`@("`@("`@("!]>#L*
M("`@("`@("`@("`@;7D@)&5X=')A8W1?;F%M92`]("0Q.PH@("`@("`@("`@
M("!M>2`D9&5S=%]N86UE(#T@1FEL93HZ4W!E8RT^8V%T9FEL92@D14Y6>U!!
M4E]414U0?2P@)&5X=')A8W1?;F%M92D["B`@("`@("`@("`@(&EF("@M9B`D
M9&5S=%]N86UE("8F("US(%\@/3T@)&UE;6)E<BT^=6YC;VUP<F5S<V5D4VEZ
M92@I*2!["B`@("`@("`@("`@("`@("!O=71S*'%Q*%-K:7!P:6YG("(D;65M
M8F5R7VYA;64B('-I;F-E(&ET(&%L<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N
M86UE(BDI.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@
M;W5T<RAQ<2A%>'1R86-T:6YG("(D;65M8F5R7VYA;64B('1O("(D9&5S=%]N
M86UE(BDI.PH@("`@("`@("`@("`@("`@)&UE;6)E<BT^97AT<F%C=%1O1FEL
M94YA;65D*"1D97-T7VYA;64I.PH@("`@("`@("`@("`@("`@8VAM;V0H,#4U
M-2P@)&1E<W1?;F%M92D@:68@)%Y/(&5Q(")H<'5X(CL*("`@("`@("`@("`@
M?0H@("`@("`@('T*("`@('T*("`@(",@?7U]"GT*(R!]?7T*"B,@268@=&AE
M<F4G<R!N;R!M86EN+G!L('1O(')U;BP@<VAO=R!U<V%G92![>WL*=6YL97-S
M("@D4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2!["B`@("!D:64@/#P@(BXB
M('5N;&5S<R!`05)'5CL*57-A9V4Z("0P(%L@+4%L:6(N<&%R(%T@6R`M261I
M<B!=(%L@+4UM;V1U;&4@72!;('-R8RYP87(@72!;('!R;V=R86TN<&P@70H@
M("`@("`@)#`@6R`M0GPM8B!=(%LM3V]U=&9I;&5=('-R8RYP87(*+@H@("`@
M)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`
M05)'5BD["GT*(R!]?7T*"G-U8B!#<F5A=&50871H('L*("`@(&UY("@D;F%M
M92D@/2!`7SL*("`@(`H@("`@<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*("`@
M(&UY("@D8F%S96YA;64L("1P871H+"`D97AT*2`]($9I;&4Z.D)A<V5N86UE
M.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I*3L*("`@(`H@("`@<F5Q=6ER
M92!&:6QE.CI0871H.PH@("`@"B`@("!&:6QE.CI0871H.CIM:W!A=&@H)'!A
M=&@I('5N;&5S<R@M92`D<&%T:"D[(",@;6MP871H(&1I97,@=VET:"!E<G)O
M<@I]"@IS=6(@<F5Q=6ER95]M;V1U;&5S('L*("`@("-L;V-A;"`D24Y#>R=#
M=V0N<&TG?2`](%]?1DE,15]?(&EF("1>3R!N92`G35-7:6XS,B<["@H@("`@
M<F5Q=6ER92!L:6(["B`@("!R97%U:7)E($1Y;F%,;V%D97(["B`@("!R97%U
M:7)E(&EN=&5G97(["B`@("!R97%U:7)E('-T<FEC=#L*("`@(')E<75I<F4@
M=V%R;FEN9W,["B`@("!R97%U:7)E('9A<G,["B`@("!R97%U:7)E($-A<G`[
M"B`@("!R97%U:7)E($-A<G`Z.DAE879Y.PH@("`@<F5Q=6ER92!%<G)N;SL*
M("`@(')E<75I<F4@17AP;W)T97(Z.DAE879Y.PH@("`@<F5Q=6ER92!%>'!O
M<G1E<CL*("`@(')E<75I<F4@1F-N=&P["B`@("!R97%U:7)E($9I;&4Z.E1E
M;7`["B`@("!R97%U:7)E($9I;&4Z.E-P96,["B`@("!R97%U:7)E(%A33&]A
M9&5R.PH@("`@<F5Q=6ER92!#;VYF:6<["B`@("!R97%U:7)E($E/.CI(86YD
M;&4["B`@("!R97%U:7)E($E/.CI&:6QE.PH@("`@<F5Q=6ER92!#;VUP<F5S
M<SHZ6FQI8CL*("`@(')E<75I<F4@07)C:&EV93HZ6FEP.PH@("`@<F5Q=6ER
M92!005(["B`@("!R97%U:7)E(%!!4CHZ2&5A=GD["B`@("!R97%U:7)E(%!!
M4CHZ1&ES=#L*("`@(')E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PH@
M("`@<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT.PH@("`@<F5Q
M=6ER92!A='1R:6)U=&5S.PH@("`@979A;"![(')E<75I<F4@0W=D('T["B`@
M("!E=F%L('L@<F5Q=6ER92!7:6XS,B!].PH@("`@979A;"![(')E<75I<F4@
M4V-A;&%R.CI5=&EL('T["B`@("!E=F%L('L@<F5Q=6ER92!!<F-H:79E.CI5
M;GII<#HZ0G5R<W0@?3L*("`@(&5V86P@>R!R97%U:7)E(%1I93HZ2&%S:#HZ
M3F%M961#87!T=7)E('T["B`@("!E=F%L('L@<F5Q=6ER92!097)L24\[(')E
M<75I<F4@4&5R;$E/.CIS8V%L87(@?3L*?0H*(R!4:&4@0R!V97)S:6]N(&]F
M('1H:7,@8V]D92!A<'!E87)S(&EN(&UY;&1R+VUK=&UP9&ER+F,*(R!4:&ES
M(&-O9&4@86QS;R!L:79E<R!I;B!005(Z.E-E='5P5&5M<"!A<R!S971?<&%R
M7W1E;7!?96YV(0IS=6(@7W-E=%]P87)?=&5M<"!["B`@("!I9B`H9&5F:6YE
M9"`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO
M*2!["B`@("`@("`@)'!A<E]T96UP(#T@)#$["B`@("`@("`@<F5T=7)N.PH@
M("`@?0H*("`@(&9O<F5A8V@@;7D@)'!A=&@@*`H@("`@("`@("AM87`@)$5.
M5GLD7WTL('%W*"!005)?5$U01$E2(%1-4$1)4B!414U01$E2(%1%35`@5$U0
M("DI+`H@("`@("`@('%W*"!#.EQ<5$5-4"`O=&UP("X@*0H@("`@*2!["B`@
M("`@("`@;F5X="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@
M86YD("UW("1P871H.PH@("`@("`@(&UY("1U<V5R;F%M93L*("`@("`@("!M
M>2`D<'=U:60["B`@("`@("`@(R!D;V5S(&YO="!W;W)K(&5V97)Y=VAE<F4Z
M"B`@("`@("`@979A;"![*"1P=W5I9"D@/2!G971P=W5I9"@D/BD@:68@9&5F
M:6YE9"`D/CM].PH*("`@("`@("!I9B`H(&1E9FEN960H)E=I;C,R.CI,;V=I
M;DYA;64I("D@>PH@("`@("`@("`@("`D=7-E<FYA;64@/2`F5VEN,S(Z.DQO
M9VEN3F%M93L*("`@("`@("!]"B`@("`@("`@96QS:68@*&1E9FEN960@)'!W
M=6ED*2!["B`@("`@("`@("`@("1U<V5R;F%M92`]("1P=W5I9#L*("`@("`@
M("!]"B`@("`@("`@96QS92!["B`@("`@("`@("`@("1U<V5R;F%M92`]("1%
M3E9[55-%4DY!345]('Q\("1%3E9[55-%4GT@?'P@)U-94U1%32<["B`@("`@
M("`@?0H@("`@("`@("1U<V5R;F%M92`]?B!S+UQ7+U\O9SL*"B`@("`@("`@
M;7D@)'-T;7!D:7(@/2`B)'!A=&@D0V]N9FEG>U]D96QI;7UP87(M(BYU;G!A
M8VLH(D@J(BP@)'5S97)N86UE*3L*("`@("`@("!M:V1I<B`D<W1M<&1I<BP@
M,#<U-3L*("`@("`@("!I9B`H(21%3E9[4$%27T-,14%.?2!A;F0@;7D@)&UT
M:6UE(#T@*'-T870H)'!R;V=N86UE*2E;.5TI('L*("`@("`@("`@("`@;W!E
M;B`H;7D@)&9H+"`B/"(N("1P<F]G;F%M92D["B`@("`@("`@("`@('-E96L@
M)&9H+"`M,3@L(#(["B`@("`@("`@("`@('-Y<W)E860@)&9H+"!M>2`D8G5F
M+"`V.PH@("`@("`@("`@("!I9B`H)&)U9B!E<2`B7#!#04-(12(I('L*("`@
M("`@("`@("`@("`@('-E96L@)&9H+"`M-3@L(#(["B`@("`@("`@("`@("`@
M("!S>7-R96%D("1F:"P@)&)U9BP@-#$["B`@("`@("`@("`@("`@("`D8G5F
M(#U^(',O7#`O+V<["B`@("`@("`@("`@("`@("`D<W1M<&1I<B`N/2`B)$-O
M;F9I9WM?9&5L:6U]8V%C:&4M(B`N("1B=68["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@96QS92!["B`@("`@("`@("`@("`@("!M>2`D8W1X(#T@979A
M;"![(')E<75I<F4@1&EG97-T.CI32$$[($1I9V5S=#HZ4TA!+3YN97<H,2D@
M?0H@("`@("`@("`@("`@("`@("`@('Q\(&5V86P@>R!R97%U:7)E($1I9V5S
M=#HZ4TA!,3L@1&EG97-T.CI32$$Q+3YN97<@?0H@("`@("`@("`@("`@("`@
M("`@('Q\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ340U.R!$:6=E<W0Z.DU$
M-2T^;F5W('T["@H@("`@("`@("`@("`@("`@(R!7;W)K87)O=6YD(&9O<B!B
M=6<@:6X@1&EG97-T.CI32$$@-2XS."!A;F0@-2XS.0H@("`@("`@("`@("`@
M("`@;7D@)'-H85]V97)S:6]N(#T@979A;"![("1$:6=E<W0Z.E-(03HZ5D52
M4TE/3B!]('Q\(#`["B`@("`@("`@("`@("`@("!I9B`H)'-H85]V97)S:6]N
M(&5Q("<U+C,X)R!O<B`D<VAA7W9E<G-I;VX@97$@)S4N,SDG*2!["B`@("`@
M("`@("`@("`@("`@("`@)&-T>"T^861D9FEL92@D<')O9VYA;64L(")B(BD@
M:68@*"1C='@I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M96QS92!["B`@("`@("`@("`@("`@("`@("`@:68@*"1C='@@86YD(&]P96XH
M;7D@)&9H+"`B/"1P<F]G;F%M92(I*2!["B`@("`@("`@("`@("`@("`@("`@
M("`@(&)I;FUO9&4H)&9H*3L*("`@("`@("`@("`@("`@("`@("`@("`@)&-T
M>"T^861D9FEL92@D9F@I.PH@("`@("`@("`@("`@("`@("`@("`@("!C;&]S
M92@D9F@I.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M('T*"B`@("`@("`@("`@("`@("`D<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L
M:6U]8V%C:&4M(B`N("@@)&-T>"`_("1C='@M/FAE>&1I9V5S="`Z("1M=&EM
M92`I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&-L;W-E*"1F:"D["B`@
M("`@("`@?0H@("`@("`@(&5L<V4@>PH@("`@("`@("`@("`D14Y6>U!!4E]#
M3$5!3GT@/2`Q.PH@("`@("`@("`@("`D<W1M<&1I<B`N/2`B)$-O;F9I9WM?
M9&5L:6U]=&5M<"TD)"(["B`@("`@("`@?0H*("`@("`@("`D14Y6>U!!4E]4
M14U0?2`]("1S=&UP9&ER.PH@("`@("`@(&UK9&ER("1S=&UP9&ER+"`P-S4U
M.PH@("`@("`@(&QA<W0["B`@("!]"@H@("`@)'!A<E]T96UP(#T@)#$@:68@
M)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+SL*
M?0H*<W5B(%]T96UP9FEL92!["B`@("!M>2`H)&5X="P@)&-R8RD@/2!`7SL*
M("`@(&UY("@D9F@L("1F:6QE;F%M92D["@H@("`@)&9I;&5N86UE(#T@(B1P
M87)?=&5M<"\D8W)C)&5X="(["@H@("`@:68@*"1%3E9[4$%27T-,14%.?2D@
M>PH@("`@("`@('5N;&EN:R`D9FEL96YA;64@:68@+64@)&9I;&5N86UE.PH@
M("`@("`@('!U<V@@0'1M<&9I;&4L("1F:6QE;F%M93L*("`@('T*("`@(&5L
M<V4@>PH@("`@("`@(')E='5R;B`H=6YD968L("1F:6QE;F%M92D@:68@*"UR
M("1F:6QE;F%M92D["B`@("!]"@H@("`@;W!E;B`D9F@L("<^)RP@)&9I;&5N
M86UE(&]R(&1I92`D(3L*("`@(&)I;FUO9&4H)&9H*3L*("`@(')E='5R;B@D
M9F@L("1F:6QE;F%M92D["GT*"B,@<V%M92!C;V1E(&QI=F5S(&EN(%!!4CHZ
M4V5T=7!0<F]G;F%M93HZ<V5T7W!R;V=N86UE"G-U8B!?<V5T7W!R;V=N86UE
M('L*("`@(&EF("AD969I;F5D("1%3E9[4$%27U!23T=.04U%?2!A;F0@)$5.
M5GM005)?4%)/1TY!345](#U^("\H+BLI+RD@>PH@("`@("`@("1P<F]G;F%M
M92`]("0Q.PH@("`@?0H*("`@("1P<F]G;F%M92!\?#T@)#`["@H@("`@:68@
M*"1%3E9[4$%27U1%35!](&%N9"!I;F1E>"@D<')O9VYA;64L("1%3E9[4$%2
M7U1%35!]*2`^/2`P*2!["B`@("`@("`@)'!R;V=N86UE(#T@<W5B<W1R*"1P
M<F]G;F%M92P@<FEN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`K
M(#$I.PH@("`@?0H*("`@(&EF("@A)$5.5GM005)?4%)/1TY!345](&]R(&EN
M9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`^/2`P*2!["B`@("`@
M("`@:68@*&]P96X@;7D@)&9H+"`G/"<L("1P<F]G;F%M92D@>PH@("`@("`@
M("`@("!R971U<FX@:68@+7,@)&9H.PH@("`@("`@('T*("`@("`@("!I9B`H
M+7,@(B1P<F]G;F%M921#;VYF:6=[7V5X97TB*2!["B`@("`@("`@("`@("1P
M<F]G;F%M92`N/2`D0V]N9FEG>U]E>&5].PH@("`@("`@("`@("!R971U<FX[
M"B`@("`@("`@?0H@("`@?0H*("`@(&9O<F5A8V@@;7D@)&1I<B`H<W!L:70@
M+UQ1)$-O;F9I9WMP871H7W-E<'U<12\L("1%3E9[4$%42'TI('L*("`@("`@
M("!N97AT(&EF(&5X:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@)&1I<B!E<2`D
M14Y6>U!!4E]414U0?3L*("`@("`@("`D9&ER(#U^(',O7%$D0V]N9FEG>U]D
M96QI;7U<120O+SL*("`@("`@("`H*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I
M9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2(I+"!L87-T*0H@("`@
M("`@("`@("!I9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#
M;VYF:6=[7V5X97TB.PH@("`@("`@("@H)'!R;V=N86UE(#T@(B1D:7(D0V]N
M9FEG>U]D96QI;7TD<')O9VYA;64B*2P@;&%S="D*("`@("`@("`@("`@:68@
M+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B.PH@("`@?0I]"@IS
M=6(@7V9I>%]P<F]G;F%M92!["B`@("`D,"`]("1P<F]G;F%M92!\?#T@)$5.
M5GM005)?4%)/1TY!345].PH@("`@:68@*&EN9&5X*"1P<F]G;F%M92P@)$-O
M;F9I9WM?9&5L:6U]*2`\(#`I('L*("`@("`@("`D<')O9VYA;64@/2`B+B1#
M;VYF:6=[7V1E;&EM?21P<F]G;F%M92(["B`@("!]"@H@("`@(R!86%@@+2!H
M86-K('1O(&UA:V4@4%=$('=O<FL*("`@(&UY("1P=V0@/2`H9&5F:6YE9"`F
M0W=D.CIG971C=V0I(#\@0W=D.CIG971C=V0H*0H@("`@("`@("`@("`@("`@
M.B`H*&1E9FEN960@)E=I;C,R.CI'971#=V0I(#\@5VEN,S(Z.D=E=$-W9"@I
M(#H@8'!W9&`I.PH@("`@8VAO;7`H)'!W9"D["B`@("`D<')O9VYA;64@/7X@
M<R]>*#\]7"Y<+C]<421#;VYF:6=[7V1E;&EM?5Q%*2\D<'=D)$-O;F9I9WM?
M9&5L:6U]+SL*"B`@("`D14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64[
M"GT*"G-U8B!?<&%R7VEN:71?96YV('L*("`@(&EF("@@)$5.5GM005)?24Y)
M5$E!3$E:141]*RL@/3T@,2`I('L*("`@("`@("!R971U<FX["B`@("!](&5L
M<V4@>PH@("`@("`@("1%3E9[4$%27TE.251)04Q)6D5$?2`](#(["B`@("!]
M"@H@("`@9F]R("AQ=R@@4U!!5TY%1"!414U0($-,14%.($1%0E5'($-!0TA%
M(%!23T=.04U%($%21T,@05)'5E\P("D@*2!["B`@("`@("`@9&5L971E("1%
M3E9[)U!!4E\G+B1??3L*("`@('T*("`@(&9O<B`H<7<O(%1-4$1)4B!414U0
M($-,14%.($1%0E5'("\I('L*("`@("`@("`D14Y6>R=005)?)RXD7WT@/2`D
M14Y6>R=005)?1TQ/0D%,7R<N)%]](&EF(&5X:7-T<R`D14Y6>R=005)?1TQ/
M0D%,7R<N)%]].PH@("`@?0H*("`@(&UY("1P87)?8VQE86X@/2`B7U]%3E9?
M4$%27T-,14%.7U\@("`@("`@("`@("`@("`B.PH*("`@(&EF("@D14Y6>U!!
M4E]414U0?2D@>PH@("`@("`@(&1E;&5T92`D14Y6>U!!4E]#3$5!3GT["B`@
M("!]"B`@("!E;'-I9B`H(65X:7-T<R`D14Y6>U!!4E]'3$]"04Q?0TQ%04Y]
M*2!["B`@("`@("`@;7D@)'9A;'5E(#T@<W5B<W1R*"1P87)?8VQE86XL(#$R
M("L@;&5N9W1H*")#3$5!3B(I*3L*("`@("`@("`D14Y6>U!!4E]#3$5!3GT@
M/2`D,2!I9B`D=F%L=64@/7X@+UY005)?0TQ%04X]*%Q3*RDO.PH@("`@?0I]
M"@IS=6(@;W5T<R!["B`@("!R971U<FX@:68@)'%U:65T.PH@("`@:68@*"1L
M;V=F:"D@>PH@("`@("`@('!R:6YT("1L;V=F:"`B0%]<;B(["B`@("!]"B`@
M("!E;'-E('L*("`@("`@("!P<FEN="`B0%]<;B(["B`@("!]"GT*"G-U8B!I
M;FET7VEN8R!["B`@("!R97%U:7)E($-O;F9I9SL*("`@('!U<V@@0$E.0RP@
M9W)E<"!D969I;F5D+"!M87`@)$-O;F9I9SHZ0V]N9FEG>R1??2P@<7<H"B`@
M("`@("`@87)C:&QI8F5X<"!P<FEV;&EB97AP('-I=&5A<F-H97AP('-I=&5L
M:6)E>'`*("`@("`@("!V96YD;W)A<F-H97AP('9E;F1O<FQI8F5X<`H@("`@
M*3L*?0H*(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C"B,@5&AE(&UA:6X@
M<&%C:V%G92!F;W(@<V-R:7!T(&5X96-U=&EO;@H*<&%C:V%G92!M86EN.PH*
M<F5Q=6ER92!005(["G5N<VAI9G0@0$E.0RP@7"9005(Z.F9I;F1?<&%R.PI0
M05(M/FEM<&]R="A`<&%R7V%R9W,I.PH*9&EE('%Q*'!A<BYP;#H@0V%N)W0@
M;W!E;B!P97)L('-C<FEP="`B)'!R;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R
M(&1I<F5C=&]R>5QN*0H@("`@=6YL97-S("UE("1P<F]G;F%M93L*"F1O("1P
M<F]G;F%M93L*0T]213HZ97AI="@D,2D@:68@*"1`(#U^+UY?5$M?15A)5%]<
M*"A<9"LI7"DO*3L*9&EE("1`(&EF("1`.PH*?3L*"B0Z.E]?15)23U(@/2`D
M0"!I9B`D0#L*?0H*0T]213HZ97AI="@D,2D@:68@*"0Z.E]?15)23U(@/7XO
M7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)#HZ7U]%4E)/4B!I9B`D.CI?
M7T524D]2.PH*,3L*"B-L:6YE(#$P,3$*"E]?14Y$7U\*``````````````"`
M____ST$!&P,[Z````!P```#0;O__!`$``#!S__^<!0``$';__R@!```P@?__
M:`$``-"!__^\`0``((+__^`!````A/__(`(``%"%__]X`@``L(;__Z0"``!0
MA___T`(``""(__\0`P``8(C__R@#``#`B/__0`,``)")__]X`P``H(G__XP#
M``!PB___S`,``*"+___@`P``@(S__R`$```PCO__4`0``(".__]L!```L([_
M_X@$``#0C___R`0``$";__\,!0``<)___TP%``#PG___A`4``$"@___(!0``
M@*#__^@%``#PH/__)`8``!0``````````7I2``%\"`$;#`0$B`$``"`````<
M````Q&W__V`$````#@A&#@Q*#PMT!'@`/QH[*C(D(CP```!`````X'3__Q4+
M````00X(A0)!#@R'`T$.$(8$00X4@P5&#NP"`P8+#A1!PPX00<8.#$''#@A!
MQ0X$``!0````@````,!___^;`````$$."(4"00X,AP-!#A"&!$,.%(,%0PY`
M`E8*#A1#PPX00<8.#$''#@A!Q0X$0PMJ#A1%PPX00<8.#$''#@A!Q0X$```@
M````U`````R`__]0`````$$."(,"10X@`D@."$'##@0````\````^````#B`
M___=`0```$$."(4"00X,AP-##A"&!$,.%(,%10Y0`M\*#A1!PPX00<8.#$''
M#@A!Q0X$2`L`5````#@!``#8@?__0@$```!!#@B%`D$.#(<#00X0A@1##A2#
M!48.H`%/"@X40<,.$$'&#@Q!QPX(0<4.!$$+`N8*#A1!PPX00<8.#$''#@A!
MQ0X$1@L``"@```"0`0``T(+__U4!````00X(A@)!#@R#`T,.(`--`0X,0<,.
M"$'&#@0`*````+P!```$A/__DP````!!#@B#`D4.(&T*#@A#PPX$0@L"5@X(
M1,,.!``\````Z`$``'B$___,`````$$."(4"0PX,AP-##A"&!$$.%(,%1@[`
M(`**"@X40<,.$$'&#@Q!QPX(0<4.!$0+%````"@"```(A?__-`````!##B!P
M#@0`%````$`"```PA?__60````!##C`"50X$-````%@"``!XA?__P0````!!
M#@B'`D$.#(8#00X0@P1&#L!``J8*#A!!PPX,0<8."$''#@1&"P`0````D`(`
M`!"&__\%`````````#P```"D`@``#(;__\4!````00X(A0)!#@R'`T$.$(8$
M00X4@P5&#M`@`FD*#A1!PPX00<8.#$''#@A!Q0X$00L0````Y`(``)R'__\M
M`````````#P```#X`@``N(?__^``````00X(@P)##B`"7PH."$'##@1$"P)3
M"@X(1L,.!$<+0PH."$/##@1!"TL."$'##@0L````.`,``%B(__^O`0```$$.
M"(<"00X,A@-##D`#6P$*#@Q!Q@X(0<<.!$8+```8````:`,``-B)__]$````
M`%,.(&L*#@1""P``&````(0#```,BO__)`````!##B!6"@X$1PL``#P```"@
M`P``((K__Q(!````00X(A0)!#@R'`T8.$(8$00X4@P5(#F`"B`H.%$'##A!!
MQ@X,0<<."$'%#@1#"P!`````X`,```"+__]P"P```$$."(4"00X,AP-!#A"&
M!$$.%(,%1@ZP@@(#H0(*#A1!PPX00<8.#$''#@A!Q0X$00L``#P````D!```
M+);__RL$````00X(A0)!#@R'`T$.$(8$00X4@P5##D`#;P(*#A1!PPX00<8.
M#$''#@A!Q0X$1@LT````9`0``!R:__]S`````$$."(8"00X,@P-##B`"7PH.
M#$'##@A!Q@X$00M##@Q#PPX(0<8.!!0```"<!```9)K__TD`````0PX@`D4.
M!"@```"T!```C&W__^0!````00X(A0)"#05(A@.#!`.(`0K#0<9!Q0P$!$$+
M'````.`$``!PFO__.@````!!#@B#`DX.(&D."$'##@0X``````4``)":__]A
M`````$$."(4"00X,AP-##A"&!$$.%(,%3@XP`D@.%$'##A!!Q@X,0<<."$'%
M#@00````/`4``,2:__\"````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!`F@0(()H$"``````!`````0````$````(`@```0``
M`!0"```!````'P(```$````I`@```0```#<"```!````1`(```$```"3`@``
M#P````<$```,`````),$"`T```!4Q00(&0```,@^!0@;````!````!H```#,
M/@4('`````0```#U_O]OK($$"`4```"TB00(!@````2#!`@*````E@4```L`
M```0````%0`````````#`````$`%"`(````H`@``%````!$````7````V)`$
M"!$```"PD`0($@```"@````3````"````/[__V\@D`0(____;P(```#P__]O
M2H\$"```````````````````````````````````````````````````````
M``````````````#4/@4(``````````!&DP0(5I,$"&:3!`AVDP0(AI,$"):3
M!`BFDP0(MI,$",:3!`C6DP0(YI,$"/:3!`@&E`0(%I0$"":4!`@VE`0(1I0$
M"%:4!`AFE`0(=I0$"(:4!`B6E`0(II0$"+:4!`C&E`0(UI0$".:4!`CVE`0(
M!I4$"!:5!`@FE00(-I4$"$:5!`A6E00(9I4$"':5!`B&E00(EI4$"*:5!`BV
ME00(QI4$"-:5!`CFE00(]I4$"`:6!`@6E@0()I8$"#:6!`A&E@0(5I8$"&:6
M!`AVE@0(AI8$"):6!`BFE@0(MI8$",:6!`C6E@0(YI8$"/:6!`@&EP0(%I<$
M"":7!`@VEP0(1I<$"%:7!`AFEP0(=I<$"(:7!`@``````````/____^@R`0(
M1T-#.B`H1TY5*2`T+C@N,@``+G-H<W1R=&%B`"YI;G1E<G``+FYO=&4N04))
M+71A9P`N;F]T92YG;G4N8G5I;&0M:60`+F=N=2YH87-H`"YD>6YS>6T`+F1Y
M;G-T<@`N9VYU+G9E<G-I;VX`+F=N=2YV97)S:6]N7W(`+G)E;"YD>6X`+G)E
M;"YP;'0`+FEN:70`+G1E>'0`+F9I;FD`+G)O9&%T80`N96A?9G)A;65?:&1R
M`"YE:%]F<F%M90`N:6YI=%]A<G)A>0`N9FEN:5]A<G)A>0`N:F-R`"YD>6YA
M;6EC`"YG;W0`+F=O="YP;'0`+F1A=&$`+F)S<P`N8V]M;65N=```````````
M``````````````````````````````````````````````L````!`````@``
M`%2!!`A4`0``$P```````````````0`````````3````!P````(```!H@00(
M:`$``"````````````````0`````````(0````<````"````B($$"(@!```D
M```````````````$`````````#0```#V__]O`@```*R!!`BL`0``6`$```4`
M````````!`````0````^````"P````(````$@P0(!`,``+`&```&`````0``
M``0````0````1@````,````"````M(D$"+0)``"6!0`````````````!````
M`````$X```#___]O`@```$J/!`A*#P``U@````4``````````@````(```!;
M````_O__;P(````@D`0((!```)`````&`````@````0`````````:@````D`
M```"````L)`$"+`0```H````!0`````````$````"````',````)`````@``
M`-B0!`C8$```*`(```4````,````!`````@```!\`````0````8`````DP0(
M`!,``",```````````````0`````````=P````$````&````,),$"#`3``!@
M!``````````````0````!````((````!````!@```)"7!`B0%P``PBT`````
M````````$`````````"(`````0````8```!4Q00(5$4``!0`````````````
M``0`````````C@````$````"````:,4$"&A%``#X7@`````````````(````
M`````)8````!`````@```&`D!0A@I```[```````````````!`````````"D
M`````0````(```!,)04(3*4``%`%``````````````0`````````K@````X`
M```#````R#X%",BN```$```````````````$`````````+H````/`````P``
M`,P^!0C,K@``!```````````````!`````````#&`````0````,```#0/@4(
MT*X```0```````````````0`````````RP````8````#````U#X%"-2N```H
M`0``!@`````````$````"````-0````!`````P```/P_!0C\KP``!```````
M````````!`````0```#9`````0````,`````0`4(`+```"`!````````````
M``0````$````X@````$````#````($$%"""Q```0```````````````$````
M`````.@````(`````P```$!!!0@PL0``-!``````````````(`````````#M
M`````0```#``````````,+$``!$```````````````$````!`````0````,`
B`````````````$&Q``#V```````````````!````````````
